{
    "$graph": [
        {
            "class": "CommandLineTool",
            "label": "FragGeneScan: find (fragmented) genes in short reads",
            "doc": "FragGeneScan is an application for finding (fragmented) genes in short\nreads. It can also be applied to predict prokaryotic genes in incomplete\nassemblies or complete genomes.\n\nFragGeneScan was first released through omics website (http://omics.informatics.indiana.edu/FragGeneScan/)\nin March 2010, where you can find its old releases. FragGeneScan migrated to SourceForge in October, 2013\n(https://sourceforge.net/projects/fraggenescan/).\n\nVersion 1.20 can be downloaded here:\nhttps://sourceforge.net/projects/fraggenescan/files/\n",
            "baseCommand": "FragGeneScan",
            "requirements": [
                {
                    "listing": [
                        {
                            "entryname": "train/model",
                            "entry": "$(inputs.model.main)"
                        },
                        {
                            "entryname": "train/gene",
                            "entry": "$(inputs.model.prob_forward)"
                        },
                        {
                            "entryname": "train/rgene",
                            "entry": "$(inputs.model.prob_backward)"
                        },
                        {
                            "entryname": "train/noncoding",
                            "entry": "$(inputs.model.prob_noncoding)"
                        },
                        {
                            "entryname": "train/start",
                            "entry": "$(inputs.model.prob_start)"
                        },
                        {
                            "entryname": "train/stop",
                            "entry": "$(inputs.model.prob_stop)"
                        },
                        {
                            "entryname": "train/start1",
                            "entry": "$(inputs.model.prob_start1)"
                        },
                        {
                            "entryname": "train/stop1",
                            "entry": "$(inputs.model.prob_stop1)"
                        },
                        {
                            "entryname": "train/pwm",
                            "entry": "$(inputs.model.pwm_dist)"
                        }
                    ],
                    "class": "InitialWorkDirRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMax": 1,
                    "ramMin": 1024,
                    "class": "ResourceRequirement"
                },
                {
                    "types": [
                        {
                            "type": "record",
                            "name": "#FragGeneScan-model.yaml/model",
                            "fields": [
                                {
                                    "name": "#FragGeneScan-model.yaml/model/main",
                                    "type": "File"
                                },
                                {
                                    "name": "#FragGeneScan-model.yaml/model/prob_forward",
                                    "type": "File",
                                    "label": "Forward probability model"
                                },
                                {
                                    "name": "#FragGeneScan-model.yaml/model/prob_backward",
                                    "type": "File",
                                    "label": "Backward probability model"
                                },
                                {
                                    "name": "#FragGeneScan-model.yaml/model/prob_noncoding",
                                    "type": "File",
                                    "label": "Noncoding probability model"
                                },
                                {
                                    "name": "#FragGeneScan-model.yaml/model/prob_start",
                                    "type": "File",
                                    "label": "Start probability model"
                                },
                                {
                                    "name": "#FragGeneScan-model.yaml/model/prob_stop",
                                    "type": "File",
                                    "label": "Stop probability model"
                                },
                                {
                                    "name": "#FragGeneScan-model.yaml/model/prob_start1",
                                    "type": "File",
                                    "label": "Start1 probability model"
                                },
                                {
                                    "name": "#FragGeneScan-model.yaml/model/prob_stop1",
                                    "type": "File",
                                    "label": "Stop1 probability model"
                                },
                                {
                                    "name": "#FragGeneScan-model.yaml/model/pwm_dist",
                                    "type": "File",
                                    "label": "pwm distribution"
                                }
                            ]
                        }
                    ],
                    "class": "SchemaDefRequirement"
                }
            ],
            "hints": [
                {
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_011929"
                            ],
                            "version": [
                                "1.20"
                            ],
                            "package": "fraggenescan"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "doc": "True if the sequence file has complete genomic sequences\nFalse if the sequence file has short sequence reads\n",
                    "type": "boolean",
                    "inputBinding": {
                        "valueFrom": "${ if (self) {\n     return [ \"-w\", \"1\" ];\n   } else {\n     return [ \"-w\", \"0\" ];\n   }\n }\n"
                    },
                    "id": "#FragGeneScan1_20.cwl/completeSeq"
                },
                {
                    "type": "#FragGeneScan-model.yaml/model",
                    "id": "#FragGeneScan1_20.cwl/model"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "inputBinding": {
                        "prefix": "-s"
                    },
                    "id": "#FragGeneScan1_20.cwl/sequence"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "-p"
                    },
                    "id": "#FragGeneScan1_20.cwl/threadNumber"
                }
            ],
            "arguments": [
                {
                    "prefix": "-o",
                    "valueFrom": "$(runtime.outdir)/predicted_cds"
                },
                {
                    "prefix": "-t",
                    "valueFrom": "model"
                }
            ],
            "id": "#FragGeneScan1_20.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute",
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "outputBinding": {
                        "glob": "predicted_cds.faa"
                    },
                    "id": "#FragGeneScan1_20.cwl/predicted_CDS_aa"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "outputBinding": {
                        "glob": "predicted_cds.ffn"
                    },
                    "id": "#FragGeneScan1_20.cwl/predicted_CDS_nuc"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "InterProScan: protein sequence classifier",
            "doc": "Version 5.21-60 can be downloaded here:\nhttps://github.com/ebi-pf-team/interproscan/wiki/HowToDownload\n\nDocumentation on how to run InterProScan 5 can be found here:\nhttps://github.com/ebi-pf-team/interproscan/wiki/HowToRun\n",
            "requirements": [
                {
                    "ramMin": 10240,
                    "coresMin": 3,
                    "class": "ResourceRequirement"
                },
                {
                    "types": [
                        {
                            "type": "enum",
                            "name": "#InterProScan-apps.yaml/apps",
                            "symbols": [
                                "#InterProScan-apps.yaml/apps/TIGRFAM",
                                "#InterProScan-apps.yaml/apps/SFLD",
                                "#InterProScan-apps.yaml/apps/SUPERFAMILY",
                                "#InterProScan-apps.yaml/apps/Gene3D",
                                "#InterProScan-apps.yaml/apps/Hamap",
                                "#InterProScan-apps.yaml/apps/Coils",
                                "#InterProScan-apps.yaml/apps/ProSiteProfiles",
                                "#InterProScan-apps.yaml/apps/SMART",
                                "#InterProScan-apps.yaml/apps/CDD",
                                "#InterProScan-apps.yaml/apps/PRINTS",
                                "#InterProScan-apps.yaml/apps/PIRSF",
                                "#InterProScan-apps.yaml/apps/ProSitePatterns",
                                "#InterProScan-apps.yaml/apps/Pfam",
                                "#InterProScan-apps.yaml/apps/ProDom",
                                "#InterProScan-apps.yaml/apps/MobiDBLite"
                            ]
                        },
                        {
                            "type": "enum",
                            "name": "#InterProScan-protein_formats.yaml/protein_formats",
                            "symbols": [
                                "#InterProScan-protein_formats.yaml/protein_formats/TSV",
                                "#InterProScan-protein_formats.yaml/protein_formats/XML",
                                "#InterProScan-protein_formats.yaml/protein_formats/GFF3"
                            ]
                        }
                    ],
                    "class": "SchemaDefRequirement"
                }
            ],
            "hints": [
                {
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_005829"
                            ],
                            "version": [
                                "5.21-60"
                            ],
                            "package": "interproscan"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "#InterProScan-apps.yaml/apps"
                        }
                    ],
                    "inputBinding": {
                        "itemSeparator": ",",
                        "prefix": "--applications"
                    },
                    "id": "#InterProScan5.21-60.cwl/applications"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--input"
                    },
                    "id": "#InterProScan5.21-60.cwl/proteinFile"
                }
            ],
            "baseCommand": "interproscan.sh",
            "arguments": [
                {
                    "valueFrom": "$(inputs.proteinFile.nameroot).i5_annotations",
                    "prefix": "--outfile"
                },
                {
                    "valueFrom": "TSV",
                    "prefix": "--formats"
                },
                "--disable-precalc",
                "--goterms",
                "--pathways",
                {
                    "valueFrom": "$(runtime.tmpdir)",
                    "prefix": "--tempdir"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "https://www.iana.org/assignments/media-types/text/tab-separated-values",
                    "outputBinding": {
                        "glob": "$(inputs.proteinFile.nameroot).i5_annotations"
                    },
                    "id": "#InterProScan5.21-60.cwl/i5Annotations"
                }
            ],
            "id": "#InterProScan5.21-60.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "coresMax": 1,
                    "ramMin": 1024,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "label": "single-line sequences only",
                    "format": "http://edamontology.org/format_1929",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#RevReadSort.cwl/sequences"
                }
            ],
            "baseCommand": "RevReadSort.pl",
            "arguments": [
                {
                    "valueFrom": "$(inputs.sequences.basename)_revsort.fasta",
                    "position": 2
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "outputBinding": {
                        "glob": "$(inputs.sequences.basename)_revsort.fasta"
                    },
                    "id": "#RevReadSort.cwl/rev_sorted_sequences"
                }
            ],
            "id": "#RevReadSort.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMax": 1,
                    "ramMin": 100,
                    "class": "ResourceRequirement"
                },
                {
                    "types": [
                        {
                            "type": "enum",
                            "name": "#biom-convert-table.yaml/table_type",
                            "label": "The type of the table to produce",
                            "symbols": [
                                "#biom-convert-table.yaml/table_type/OTU table",
                                "#biom-convert-table.yaml/table_type/Pathway table",
                                "#biom-convert-table.yaml/table_type/Function table",
                                "#biom-convert-table.yaml/table_type/Ortholog table",
                                "#biom-convert-table.yaml/table_type/Gene table",
                                "#biom-convert-table.yaml/table_type/Metabolite table",
                                "#biom-convert-table.yaml/table_type/Taxon table",
                                "#biom-convert-table.yaml/table_type/Table"
                            ]
                        }
                    ],
                    "class": "SchemaDefRequirement"
                }
            ],
            "hints": [
                {
                    "packages": [
                        {
                            "specs": [
                                "https://doi.org/10.1186/2047-217X-1-7"
                            ],
                            "version": [
                                "2.1.6"
                            ],
                            "package": "biom-format"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3746",
                    "inputBinding": {
                        "prefix": "--input-fp"
                    },
                    "id": "#biom-convert.cwl/biom"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "label": "Output as HDF5-formatted table.",
                    "inputBinding": {
                        "prefix": "--to-hdf5"
                    },
                    "id": "#biom-convert.cwl/hdf5"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "The observation metadata to include from the input BIOM table file when\ncreating a tsv table file. By default no observation metadata will be\nincluded.\n",
                    "inputBinding": {
                        "prefix": "--header-key"
                    },
                    "id": "#biom-convert.cwl/header_key"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "label": "Output as JSON-formatted table.",
                    "inputBinding": {
                        "prefix": "--to-json"
                    },
                    "id": "#biom-convert.cwl/json"
                },
                {
                    "type": [
                        "null",
                        "#biom-convert-table.yaml/table_type"
                    ],
                    "inputBinding": {
                        "prefix": "--table-type"
                    },
                    "id": "#biom-convert.cwl/table_type"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "label": "Output as TSV-formatted (classic) table.",
                    "inputBinding": {
                        "prefix": "--to-tsv"
                    },
                    "id": "#biom-convert.cwl/tsv"
                }
            ],
            "baseCommand": [
                "biom",
                "convert"
            ],
            "arguments": [
                {
                    "valueFrom": "${ var ext = \"\";\n   if (inputs.json) { ext = \".json\"; }\n   if (inputs.hdf5) { ext = \".hdf5\"; }\n   if (inputs.tsv) { ext = \".tsv\"; }\n   return inputs.biom.nameroot + ext; }\n",
                    "prefix": "--output-fp"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.biom.nameroot)*"
                    },
                    "id": "#biom-convert.cwl/result"
                }
            ],
            "id": "#biom-convert.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "coresMax": 1,
                    "ramMin": 100,
                    "class": "ResourceRequirement"
                },
                {
                    "types": [
                        {
                            "$import": "#biom-convert-table.yaml/table_type"
                        }
                    ],
                    "class": "SchemaDefRequirement"
                }
            ],
            "hints": [
                {
                    "packages": [
                        {
                            "specs": [
                                "https://doi.org/10.1186/2047-217X-1-7"
                            ],
                            "version": [
                                "2.1.6"
                            ],
                            "package": "biom-format"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "format": "http://edamontology.org/format_3746",
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--input-fp"
                    },
                    "id": "#biom-summarize_table.cwl/biom"
                }
            ],
            "baseCommand": [
                "biom",
                "summarize-table"
            ],
            "arguments": [
                {
                    "valueFrom": "otu_table_summary.txt",
                    "prefix": "--output-fp"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "otu_table_summary.txt"
                    },
                    "id": "#biom-summarize_table.cwl/otu_table_summary"
                }
            ],
            "id": "#biom-summarize_table.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "replace problem characters from FASTA headers with dashes",
            "requirements": [
                {
                    "coresMax": 1,
                    "ramMin": 1024,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "streamable": true,
                    "format": "http://edamontology.org/format_1929",
                    "id": "#clean_fasta_headers.cwl/sequences"
                }
            ],
            "stdin": "$(inputs.sequences.path)",
            "baseCommand": [
                "tr",
                " /|<_;#",
                "-------"
            ],
            "stdout": "$(inputs.sequences.nameroot).cleaned.fasta",
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "id": "#clean_fasta_headers.cwl/sequences_with_cleaned_headers",
                    "outputBinding": {
                        "glob": "$(inputs.sequences.nameroot).cleaned.fasta"
                    }
                }
            ],
            "id": "#clean_fasta_headers.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#collate_unique_SSU_headers.cwl/hits"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#collate_unique_SSU_headers.cwl/sort_uniq_names/sorted_uniq_names",
                    "id": "#collate_unique_SSU_headers.cwl/unique_hits"
                }
            ],
            "steps": [
                {
                    "run": "#extract_coord_lines.cwl",
                    "in": [
                        {
                            "source": "#collate_unique_SSU_headers.cwl/hits",
                            "id": "#collate_unique_SSU_headers.cwl/extract_coord_lines/summary"
                        }
                    ],
                    "scatter": "#collate_unique_SSU_headers.cwl/extract_coord_lines/summary",
                    "out": [
                        "#collate_unique_SSU_headers.cwl/extract_coord_lines/coord_lines"
                    ],
                    "id": "#collate_unique_SSU_headers.cwl/extract_coord_lines"
                },
                {
                    "run": {
                        "id": "#collate_unique_SSU_headers.cwl/extract_names/extract_names",
                        "class": "CommandLineTool",
                        "inputs": [
                            {
                                "type": "File",
                                "inputBinding": {
                                    "position": 1
                                },
                                "doc": "The required columns are as follows:\n(1) target name: The name of the target sequence or profile.\n",
                                "id": "#collate_unique_SSU_headers.cwl/extract_names/extract_names/coordinate_lines"
                            }
                        ],
                        "baseCommand": [
                            "awk",
                            "{print $1}"
                        ],
                        "stdout": "names",
                        "outputs": [
                            {
                                "type": "File",
                                "id": "#collate_unique_SSU_headers.cwl/extract_names/extract_names/names",
                                "outputBinding": {
                                    "glob": "names"
                                }
                            }
                        ]
                    },
                    "in": [
                        {
                            "source": "#collate_unique_SSU_headers.cwl/extract_coord_lines/coord_lines",
                            "id": "#collate_unique_SSU_headers.cwl/extract_names/coordinate_lines"
                        }
                    ],
                    "scatter": "#collate_unique_SSU_headers.cwl/extract_names/coordinate_lines",
                    "out": [
                        "#collate_unique_SSU_headers.cwl/extract_names/names"
                    ],
                    "id": "#collate_unique_SSU_headers.cwl/extract_names"
                },
                {
                    "run": {
                        "id": "#collate_unique_SSU_headers.cwl/sort_uniq_names/sort_uniq_names",
                        "class": "CommandLineTool",
                        "inputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "inputBinding": {
                                    "position": 1
                                },
                                "id": "#collate_unique_SSU_headers.cwl/sort_uniq_names/sort_uniq_names/names"
                            }
                        ],
                        "baseCommand": [
                            "sort",
                            "--unique"
                        ],
                        "stdout": "sorted_uniq_names",
                        "outputs": [
                            {
                                "type": "File",
                                "id": "#collate_unique_SSU_headers.cwl/sort_uniq_names/sort_uniq_names/sorted_uniq_names",
                                "outputBinding": {
                                    "glob": "sorted_uniq_names"
                                }
                            }
                        ]
                    },
                    "in": [
                        {
                            "source": "#collate_unique_SSU_headers.cwl/extract_names/names",
                            "id": "#collate_unique_SSU_headers.cwl/sort_uniq_names/names"
                        }
                    ],
                    "out": [
                        "#collate_unique_SSU_headers.cwl/sort_uniq_names/sorted_uniq_names"
                    ],
                    "id": "#collate_unique_SSU_headers.cwl/sort_uniq_names"
                }
            ],
            "id": "#collate_unique_SSU_headers.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMax": 1,
                    "ramMin": 100,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "streamable": true,
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#concatenate.cwl/files"
                }
            ],
            "baseCommand": "cat",
            "stdout": "result",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "result",
                        "outputEval": "${ self[0].format = inputs.files[0].format;\n   return self; }\n"
                    },
                    "id": "#concatenate.cwl/result"
                }
            ],
            "id": "#concatenate.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMax": 1,
                    "ramMin": 100,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "streamable": true,
                    "format": "http://edamontology.org/format_1929",
                    "id": "#count_fasta.cwl/sequences"
                }
            ],
            "stdin": "$(inputs.sequences.path)",
            "baseCommand": [
                "grep",
                "-c",
                "^>"
            ],
            "stdout": "count",
            "outputs": [
                {
                    "type": "int",
                    "outputBinding": {
                        "glob": "count",
                        "loadContents": true,
                        "outputEval": "$(Number(self[0].contents))"
                    },
                    "id": "#count_fasta.cwl/count"
                }
            ],
            "id": "#count_fasta.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMax": 1,
                    "ramMin": 100,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "streamable": true,
                    "format": "http://edamontology.org/format_1930",
                    "id": "#count_fastq.cwl/sequences"
                }
            ],
            "baseCommand": [
                "bash"
            ],
            "arguments": [
                {
                    "valueFrom": "expr \\$(wc -l < $(inputs.sequences.path)) / 4\n",
                    "prefix": "-c"
                }
            ],
            "stdout": "count",
            "outputs": [
                {
                    "type": "int",
                    "outputBinding": {
                        "glob": "count",
                        "loadContents": true,
                        "outputEval": "$(Number(self[0].contents))"
                    },
                    "id": "#count_fastq.cwl/count"
                }
            ],
            "id": "#count_fastq.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "categorise sequences",
            "requirements": [
                {
                    "coresMax": 1,
                    "ramMin": 1024,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_007173"
                            ],
                            "version": [
                                "1.65",
                                "1.66",
                                "1.69"
                            ],
                            "package": "biopython"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "streamable": true,
                    "format": "https://www.iana.org/assignments/media-types/application/json",
                    "id": "#create_categorisations.cwl/cds_idset"
                },
                {
                    "type": "File",
                    "streamable": true,
                    "format": "https://www.iana.org/assignments/media-types/application/json",
                    "id": "#create_categorisations.cwl/ipr_idset"
                },
                {
                    "type": "File",
                    "streamable": true,
                    "format": "http://edamontology.org/format_1929",
                    "id": "#create_categorisations.cwl/seqs"
                }
            ],
            "baseCommand": "python",
            "arguments": [
                {
                    "prefix": "-c",
                    "valueFrom": "import json\nfrom Bio import SeqIO\nipr_idset = frozenset(json.load(open(\"$(inputs.ipr_idset.path)\", \"r\")))\ncds_idset = frozenset(json.load(open(\"$(inputs.cds_idset.path)\", \"r\")))\nipr_output = open(\"interproscan.fasta\", \"w\")\ncds_output = open(\"pCDS.fasta\", \"w\")\nnof_output = open(\"noFunction.fasta\", \"w\")\nfor seq in SeqIO.parse(\"$(inputs.seqs.path)\", \"fasta\"):\n    ipr_seen = False\n    if seq.name in ipr_idset:\n        ipr_output.write(str(\">\" + seq.name + \"\\\\n\" + seq.seq + \"\\\\n\"))\n        ipr_seen = True\n    if seq.name in cds_idset:\n        cds_output.write(str(\">\" + seq.name + \"\\\\n\" + seq.seq + \"\\\\n\"))\n        if not ipr_seen:\n             nof_output.write(str(\">\" + seq.name + \"\\\\n\" + seq.seq + \"\\\\n\"))\n"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "streamable": true,
                    "outputBinding": {
                        "glob": "interproscan.fasta"
                    },
                    "id": "#create_categorisations.cwl/interproscan"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "streamable": true,
                    "outputBinding": {
                        "glob": "noFunction.fasta"
                    },
                    "id": "#create_categorisations.cwl/no_functions_seqs"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "streamable": true,
                    "outputBinding": {
                        "glob": "pCDS.fasta"
                    },
                    "id": "#create_categorisations.cwl/pCDS_seqs"
                }
            ],
            "id": "#create_categorisations.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "normalize to fasta",
            "doc": "normalizes input sequeces to FASTA with fixed number of sequence characters\nper line using esl-reformat from https://github.com/EddyRivasLab/easel\n",
            "requirements": [
                {
                    "coresMax": 1,
                    "ramMin": 100,
                    "class": "ResourceRequirement"
                },
                {
                    "types": [
                        {
                            "type": "record",
                            "name": "#esl-reformat-replace.yaml/replace",
                            "label": "sequence token replacement",
                            "fields": [
                                {
                                    "name": "#esl-reformat-replace.yaml/replace/find",
                                    "type": "string",
                                    "label": null,
                                    "doc": "Must be equal length with \"replace\". Each character from the input file\nwill be replaced by its counterpart (at the same position) from \"replace\"\n"
                                },
                                {
                                    "name": "#esl-reformat-replace.yaml/replace/replace",
                                    "type": "string",
                                    "label": null,
                                    "doc": "must be equal length with \"find\""
                                }
                            ]
                        }
                    ],
                    "class": "SchemaDefRequirement"
                }
            ],
            "hints": [
                {
                    "packages": [
                        {
                            "package": "easel"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "#esl-reformat-replace.yaml/replace"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--replace",
                        "valueFrom": "$(self.find):$(self.replace)"
                    },
                    "id": "#esl-reformat.cwl/replace"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 3
                    },
                    "format": [
                        "http://edamontology.org/format_1929"
                    ],
                    "id": "#esl-reformat.cwl/sequences"
                }
            ],
            "baseCommand": [
                "esl-reformat"
            ],
            "arguments": [
                {
                    "valueFrom": "fasta",
                    "position": 2
                }
            ],
            "stdout": "reformatted_sequences",
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "id": "#esl-reformat.cwl/reformatted_sequences",
                    "outputBinding": {
                        "glob": "reformatted_sequences"
                    }
                }
            ],
            "id": "#esl-reformat.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "index a sequence file for use by esl-sfetch",
            "doc": "https://github.com/EddyRivasLab/easel",
            "requirements": [
                {
                    "listing": [
                        "$(inputs.sequences)"
                    ],
                    "class": "InitialWorkDirRequirement"
                },
                {
                    "coresMax": 1,
                    "ramMin": 1024,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "packages": [
                        {
                            "package": "easel"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1,
                        "valueFrom": "$(self.basename)"
                    },
                    "format": "http://edamontology.org/format_1929",
                    "id": "#esl-sfetch-index.cwl/sequences"
                }
            ],
            "baseCommand": [
                "esl-sfetch",
                "--index"
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": ".ssi",
                    "format": "http://edamontology.org/format_1929",
                    "outputBinding": {
                        "glob": "$(inputs.sequences.basename)"
                    },
                    "id": "#esl-sfetch-index.cwl/sequences_with_index"
                }
            ],
            "id": "#esl-sfetch-index.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "extract by names from an indexed sequence file",
            "doc": "https://github.com/EddyRivasLab/easel",
            "requirements": [
                {
                    "coresMax": 1,
                    "ramMin": 100,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "packages": [
                        {
                            "package": "easel"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "label": "sequence file indexed by esl-sfetch-index",
                    "type": "File",
                    "secondaryFiles": ".ssi",
                    "inputBinding": {
                        "prefix": "-f",
                        "position": 1
                    },
                    "format": "http://edamontology.org/format_1929",
                    "id": "#esl-sfetch-manyseqs.cwl/indexed_sequences"
                },
                {
                    "type": "File",
                    "label": "sequence names to retrieve, one per line",
                    "streamable": true,
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#esl-sfetch-manyseqs.cwl/names"
                },
                {
                    "doc": "GDF format: <newname> <from> <to> <source seqname>\nspace/tabdelimited\n",
                    "type": "boolean",
                    "inputBinding": {
                        "prefix": "-C"
                    },
                    "id": "#esl-sfetch-manyseqs.cwl/names_contain_subseq_coords"
                }
            ],
            "baseCommand": [
                "esl-sfetch"
            ],
            "stdout": "$(inputs.indexed_sequences.nameroot)_$(inputs.names.nameroot).fasta",
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "id": "#esl-sfetch-manyseqs.cwl/sequences",
                    "outputBinding": {
                        "glob": "$(inputs.indexed_sequences.nameroot)_$(inputs.names.nameroot).fasta"
                    }
                }
            ],
            "id": "#esl-sfetch-manyseqs.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "requirements": [
                {
                    "coresMax": 1,
                    "ramMin": 100,
                    "class": "ResourceRequirement"
                }
            ],
            "class": "CommandLineTool",
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "streamable": true,
                    "id": "#extract_coord_lines.cwl/summary"
                }
            ],
            "baseCommand": [
                "grep",
                "-v",
                "^#"
            ],
            "successCodes": [
                0,
                1
            ],
            "stdout": "$(inputs.summary.nameroot).coord_lines",
            "outputs": [
                {
                    "type": "File",
                    "id": "#extract_coord_lines.cwl/coord_lines",
                    "outputBinding": {
                        "glob": "$(inputs.summary.nameroot).coord_lines"
                    }
                }
            ],
            "id": "#extract_coord_lines.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "coresMax": 1,
                    "ramMin": 100,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "streamable": true,
                    "id": "#extract_observations.cwl/tsv_otu_table"
                }
            ],
            "baseCommand": [
                "awk",
                "/#/ {next};{print $1}"
            ],
            "stdin": "$(inputs.tsv_otu_table.path)",
            "stdout": "observations",
            "outputs": [
                {
                    "type": "File",
                    "id": "#extract_observations.cwl/observations",
                    "outputBinding": {
                        "glob": "observations"
                    }
                }
            ],
            "id": "#extract_observations.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "coresMax": 1,
                    "ramMin": 100,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "packages": [
                        {
                            "version": [
                                "2.7"
                            ],
                            "package": "python"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "format": "https://www.iana.org/assignments/media-types/text/tab-separated-values",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#extract_sig_coords.cwl/i5_annotations"
                }
            ],
            "baseCommand": [
                "extract_sig_coords.py"
            ],
            "arguments": [
                {
                    "valueFrom": "$(inputs.i5_annotations.basename).matches_coords",
                    "position": 2
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.i5_annotations.basename).matches_coords"
                    },
                    "id": "#extract_sig_coords.cwl/matches_coords"
                }
            ],
            "id": "#extract_sig_coords.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "coresMax": 1,
                    "ramMin": 100,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-d"
                    },
                    "id": "#faselector.cwl/id_list"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "inputBinding": {
                        "prefix": "-i"
                    },
                    "id": "#faselector.cwl/sequences"
                }
            ],
            "baseCommand": "faselector",
            "arguments": [
                {
                    "valueFrom": "$(inputs.sequences.basename).keep.fasta",
                    "prefix": "-k"
                },
                {
                    "valueFrom": "$(inputs.sequences.basename).reject.fasta",
                    "prefix": "-r"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "outputBinding": {
                        "glob": "$(inputs.sequences.basename).keep.fasta"
                    },
                    "id": "#faselector.cwl/kept_sequences"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "outputBinding": {
                        "glob": "$(inputs.sequences.basename).reject.fasta"
                    },
                    "id": "#faselector.cwl/rejected_sequences"
                }
            ],
            "id": "#faselector.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "split FASTA by number of records",
            "doc": "based upon code by Maxim Scheremetjew, EMBL-EBI",
            "requirements": [
                {
                    "coresMax": 1,
                    "ramMin": 100,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_007173"
                            ],
                            "version": [
                                "1.65",
                                "1.66",
                                "1.69"
                            ],
                            "package": "biopython"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "int",
                    "id": "#fasta_chunker.cwl/chunk_size"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "id": "#fasta_chunker.cwl/seqs"
                }
            ],
            "baseCommand": "python",
            "arguments": [
                {
                    "prefix": "-c",
                    "valueFrom": "from Bio import SeqIO\ncurrentSequences = []\nfor record in SeqIO.parse(\"$(inputs.seqs.path)\", \"fasta\"):\n    currentSequences.append(record)\n    if len(currentSequences) == $(inputs.chunk_size):\n        fileName = currentSequences[0].id + \"_\" + \\\\\n                       currentSequences[-1].id + \".fasta\"\n        for char in [ \"/\", \" \", \":\" ]:\n            fileName = fileName.replace(char, \"_\")\n        SeqIO.write(currentSequences, \"$(runtime.outdir)/\"+fileName, \"fasta\")\n        currentSequences = []\n\n# write any remaining sequences\nif len(currentSequences) > 0:\n    fileName = currentSequences[0].id + \"_\" + \\\\\n                   currentSequences[-1].id + \".fasta\"\n    for char in [ \"/\", \" \", \":\" ]:\n        fileName = fileName.replace(char, \"_\")\n    SeqIO.write(currentSequences, \"$(runtime.outdir)/\"+fileName, \"fasta\")\n"
                }
            ],
            "outputs": [
                {
                    "format": "http://edamontology.org/format_1929",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "*"
                    },
                    "id": "#fasta_chunker.cwl/chunks"
                }
            ],
            "id": "#fasta_chunker.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "coresMax": 1,
                    "ramMin": 100,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_007173"
                            ],
                            "version": [
                                "1.65",
                                "1.66",
                                "1.69"
                            ],
                            "package": "biopython"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "streamable": true,
                    "format": "http://edamontology.org/format_1930",
                    "id": "#fastq_to_fasta.cwl/fastq"
                }
            ],
            "stdin": "$(inputs.fastq.path)",
            "baseCommand": [
                "python"
            ],
            "arguments": [
                {
                    "valueFrom": "import sys\nfrom Bio import SeqIO\nSeqIO.convert(sys.stdin, \"fastq\", sys.stdout, \"fasta\")\n",
                    "prefix": "-c"
                }
            ],
            "stdout": "$(inputs.fastq.basename).fasta",
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "id": "#fastq_to_fasta.cwl/fasta",
                    "outputBinding": {
                        "glob": "$(inputs.fastq.basename).fasta"
                    }
                }
            ],
            "id": "#fastq_to_fasta.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "coresMax": 1,
                    "ramMin": 10240,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_005732"
                            ],
                            "version": [
                                "8d53bbce1ffe60d9aa3357c1001599f9a882317a"
                            ],
                            "package": "owltools"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--input-file"
                    },
                    "id": "#go_summary.cwl/InterProScan_results"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--config"
                    },
                    "id": "#go_summary.cwl/config"
                }
            ],
            "baseCommand": "go_summary_pipeline-1.0.py",
            "arguments": [
                {
                    "valueFrom": "go-summary",
                    "prefix": "--output-file"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "https://www.iana.org/assignments/media-types/text/csv",
                    "outputBinding": {
                        "glob": "go-summary"
                    },
                    "id": "#go_summary.cwl/go_summary"
                },
                {
                    "type": "File",
                    "format": "https://www.iana.org/assignments/media-types/text/csv",
                    "outputBinding": {
                        "glob": "go-summary_slim"
                    },
                    "id": "#go_summary.cwl/go_summary_slim"
                }
            ],
            "id": "#go_summary.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "search profile(s) against a sequence database",
            "requirements": [
                {
                    "coresMax": 4,
                    "ramMin": 1024,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_005305"
                            ],
                            "version": [
                                "3.1b2"
                            ],
                            "package": "hmmer"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "label": "report sequences <= this E-value threshold in output",
                    "inputBinding": {
                        "prefix": "-E"
                    },
                    "id": "#hmmsearch.cwl/e_threshold"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "format": "http://edamontology.org/format_1370",
                    "id": "#hmmsearch.cwl/hmm_profiles"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#hmmsearch.cwl/sequence_query"
                }
            ],
            "baseCommand": [
                "hmmsearch"
            ],
            "arguments": [
                {
                    "valueFrom": "$(inputs.sequence_query.nameroot)_$(inputs.hmm_profiles.nameroot)_per_domain_summary.txt",
                    "prefix": "--domtblout"
                },
                {
                    "valueFrom": "$(runtime.cores)",
                    "prefix": "--cpu"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.sequence_query.nameroot)_$(inputs.hmm_profiles.nameroot)_per_domain_summary.txt"
                    },
                    "id": "#hmmsearch.cwl/per_domain_summary"
                }
            ],
            "id": "#hmmsearch.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "gather stats from InterProScan",
            "requirements": [
                {
                    "coresMax": 1,
                    "ramMin": 1024,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "packages": [
                        {
                            "package": "python"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "streamable": true,
                    "id": "#ipr_stats.cwl/iprscan"
                }
            ],
            "baseCommand": "python",
            "arguments": [
                {
                    "prefix": "-c",
                    "valueFrom": "from __future__ import print_function\nimport re\nimport json\nimport yaml\naccessionPattern = re.compile(\"(\\\\S+)_\\\\d+_\\\\d+_[+-]\")\nmatch_count = CDS_with_match_number = reads_with_match_count = 0\ncds = set(); reads = set()\nentry2protein = {}; entry2name = {}\nfor line in open(\"$(inputs.iprscan.path)\", \"r\"):\n    splitLine = line.strip().split(\"\\\\t\")\n    cdsAccessions = splitLine[0].split(\"|\")\n    for cdsAccession in cdsAccessions:\n        if len(splitLine) >= 13 and splitLine[11].startswith(\"IPR\"):\n            entry = splitLine[11]\n            entry2protein.setdefault(entry, set()).add(cdsAccession)\n            entry2name[entry] = splitLine[12]\n        cds.add(cdsAccession)\n        readAccessionMatch = re.match(accessionPattern, cdsAccession)\n        readAccession = readAccessionMatch.group(1)\n        reads.add(readAccession)\n        match_count += 1\nCDS_with_match_count = len(cds)\nwithFunctionFaaList = sorted(list(cds))\nwith open(\"id_list.txt\", \"w\") as idFile:\n    for id in withFunctionFaaList:\n        idFile.write(id + \"\\\\n\")\nreads_with_match_count = len(reads)\nwith open(\"reads.json\", \"w\") as readsFile:\n    json.dump(list(reads), readsFile)\nwith open(\"ipr_entry_maps.yaml\", \"w\") as mapsFile:\n    yaml.dump({\"entry2protein\": entry2protein,\n               \"entry2name\": entry2name}, mapsFile)\nprint(json.dumps({\n    \"match_count\": match_count,\n    \"CDS_with_match_count\": CDS_with_match_count,\n    \"reads_with_match_count\": reads_with_match_count,\n    \"id_list\": {\n        \"class\": \"File\",\n        \"path\": \"$(runtime.outdir)/id_list.txt\" },\n    \"ipr_entry_maps\": {\n        \"class\": \"File\",\n        \"format\": \"https://www.iana.org/assignments/media-types/application/yaml\",\n        \"path\": \"$(runtime.outdir)/ipr_entry_maps.yaml\" },\n    \"reads\": {\n        \"class\": \"File\",\n        \"format\": \"https://www.iana.org/assignments/media-types/application/json\",\n        \"path\": \"$(runtime.outdir)/reads.json\" } }))\n"
                }
            ],
            "stdout": "cwl.output.json",
            "outputs": [
                {
                    "type": "int",
                    "id": "#ipr_stats.cwl/CDS_with_match_count"
                },
                {
                    "type": "File",
                    "streamable": true,
                    "id": "#ipr_stats.cwl/id_list"
                },
                {
                    "type": "File",
                    "streamable": true,
                    "format": "https://www.iana.org/assignments/media-types/application/yaml",
                    "id": "#ipr_stats.cwl/ipr_entry_maps"
                },
                {
                    "type": "int",
                    "id": "#ipr_stats.cwl/match_count"
                },
                {
                    "type": "File",
                    "streamable": true,
                    "format": "https://www.iana.org/assignments/media-types/application/json",
                    "id": "#ipr_stats.cwl/reads"
                },
                {
                    "type": "int",
                    "id": "#ipr_stats.cwl/reads_with_match_count"
                }
            ],
            "id": "#ipr_stats.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "visualize using krona",
            "requirements": [
                {
                    "coresMax": 1,
                    "ramMin": 1024,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_012785"
                            ],
                            "version": [
                                "2.3",
                                "2.7"
                            ],
                            "package": "krona"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "format": "https://www.iana.org/assignments/media-types/text/tab-separated-values",
                    "label": "Tab-delimited text file",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#krona.cwl/otu_counts"
                }
            ],
            "baseCommand": "ktImportText",
            "arguments": [
                {
                    "valueFrom": "$(inputs.otu_counts.nameroot).html",
                    "prefix": "-o"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "https://www.iana.org/assignments/media-types/text/html",
                    "outputBinding": {
                        "glob": "$(inputs.otu_counts.nameroot).html"
                    },
                    "id": "#krona.cwl/otu_visualization"
                }
            ],
            "id": "#krona.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "coresMax": 1,
                    "ramMin": 1024,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "packages": [
                        {
                            "package": "python"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "streamable": true,
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#krona_setup.cwl/qiime_taxonomy"
                }
            ],
            "baseCommand": "krona_setup.py",
            "arguments": [
                {
                    "valueFrom": "$(inputs.qiime_taxonomy.nameroot).krona-input.txt",
                    "position": 2
                },
                {
                    "valueFrom": "$(inputs.qiime_taxonomy.nameroot).kingdom-counts.txt",
                    "position": 3
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "streamable": true,
                    "outputBinding": {
                        "glob": "$(inputs.qiime_taxonomy.nameroot).kingdom-counts.txt"
                    },
                    "id": "#krona_setup.cwl/kingdom_counts"
                },
                {
                    "type": "File",
                    "streamable": true,
                    "format": "https://www.iana.org/assignments/media-types/text/tab-separated-values",
                    "outputBinding": {
                        "glob": "$(inputs.qiime_taxonomy.nameroot).krona-input.txt"
                    },
                    "id": "#krona_setup.cwl/krona_input"
                }
            ],
            "id": "#krona_setup.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "coresMax": 1,
                    "ramMin": 100,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "label": "append to old header rather than replacing",
                    "inputBinding": {
                        "prefix": "-a"
                    },
                    "id": "#map_fa_headers.cwl/append"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-m"
                    },
                    "id": "#map_fa_headers.cwl/header_mapping"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "inputBinding": {
                        "prefix": "-i"
                    },
                    "id": "#map_fa_headers.cwl/sequences"
                }
            ],
            "baseCommand": [
                "map_fa_headers"
            ],
            "arguments": [
                {
                    "valueFrom": "$(inputs.sequences.basename).newheaders.fasta",
                    "prefix": "-o"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "outputBinding": {
                        "glob": "$(inputs.sequences.basename).newheaders.fasta"
                    },
                    "id": "#map_fa_headers.cwl/relabeled_sequences"
                }
            ],
            "id": "#map_fa_headers.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "listing": [
                        {
                            "entryname": "hmmer.txt",
                            "entry": "$(inputs.unique_rRNA_hits)"
                        },
                        {
                            "entryname": "hmmer.16s.txt",
                            "entry": "$(inputs.16s_rRNA_hmmer_matches)"
                        },
                        {
                            "entryname": "hmmer.23s.txt",
                            "entry": "$(inputs.23s_rRNA_hmmer_matches)"
                        },
                        {
                            "entryname": "hmmer.5s.txt",
                            "entry": "$(inputs.5s_rRNA_hmmer_matches)"
                        }
                    ],
                    "class": "InitialWorkDirRequirement"
                },
                {
                    "coresMax": 1,
                    "ramMin": 1024,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#mask_RNA.cwl/16s_rRNA_hmmer_matches"
                },
                {
                    "type": "File",
                    "id": "#mask_RNA.cwl/23s_rRNA_hmmer_matches"
                },
                {
                    "type": "File",
                    "id": "#mask_RNA.cwl/5s_rRNA_hmmer_matches"
                },
                {
                    "type": "File",
                    "id": "#mask_RNA.cwl/sequences"
                },
                {
                    "type": "File",
                    "id": "#mask_RNA.cwl/tRNA_matches"
                },
                {
                    "type": "File",
                    "id": "#mask_RNA.cwl/unique_rRNA_hits"
                },
                {
                    "type": "File",
                    "id": "#mask_RNA.cwl/unique_tRNA_hits"
                }
            ],
            "baseCommand": "rnaMaskingStep.py",
            "arguments": [
                {
                    "prefix": "--hmmer",
                    "valueFrom": "hmmer.txt"
                },
                {
                    "prefix": "--nhmmer",
                    "valueFrom": "$(inputs.tRNA_matches.path)"
                },
                {
                    "prefix": "--seq_id",
                    "valueFrom": "$(inputs.unique_tRNA_hits.path)"
                },
                {
                    "prefix": "--input",
                    "valueFrom": "$(inputs.sequences.path)"
                },
                {
                    "prefix": "--output",
                    "valueFrom": "masked_sequences.fasta"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "outputBinding": {
                        "glob": "masked_sequences.fasta"
                    },
                    "id": "#mask_RNA.cwl/masked_sequences"
                }
            ],
            "id": "#mask_RNA.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "generate a modified tsv taxonomy file that works with the current web app",
            "requirements": [
                {
                    "coresMax": 1,
                    "ramMin": 100,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "packages": [
                        {
                            "package": "python"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#modify_taxonomy_table.cwl/otu_table"
                },
                {
                    "type": "File",
                    "id": "#modify_taxonomy_table.cwl/uclust_log"
                }
            ],
            "baseCommand": "python",
            "arguments": [
                {
                    "prefix": "-c",
                    "valueFrom": "from __future__ import print_function\nunassignedOTUCount = \"0\"\nwith open(\"$(inputs.uclust_log.path)\", \"r\") as uclog:\n    for f in uclog:\n        if f.startswith(\"Num failures:\"):\n            unassignedOTUCount = f.rstrip().split(\":\")[1]\nwith open(\"$(inputs.otu_table.path)\", \"r\") as table:\n    for line in table:\n        line = line.rstrip()\n        if line.startswith(\"#\"):\n            if line.startswith(\"#OTU\"):\n                print(line)\n        else:\n            l = line.rstrip().split(\"\\\\t\")\n            obsCount = l[1].replace(\".0\", \"\")\n            lineage = l[-1].replace(\" \", \"\")\n            tax = \"Root;\" + lineage\n            print(l[0] + \"\\\\t\" + obsCount + \"\\\\t\" + tax)\n    if unassignedOTUCount != \"0\":\n        print(\"0\" + \"\\\\t\" + unassignedOTUCount + \"\\\\t\" + \"Root\")\n"
                }
            ],
            "stdout": "qiime_assigned_taxonomy.txt",
            "outputs": [
                {
                    "type": "File",
                    "id": "#modify_taxonomy_table.cwl/qiime_assigned_taxonomy",
                    "outputBinding": {
                        "glob": "qiime_assigned_taxonomy.txt"
                    }
                }
            ],
            "id": "#modify_taxonomy_table.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "search profile(s) against a sequence database",
            "requirements": [
                {
                    "coresMax": 4,
                    "ramMin": 1024,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_005305"
                            ],
                            "version": [
                                "3.1b2"
                            ],
                            "package": "hmmer"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "label": "report sequences >= this bit score threshold in output",
                    "inputBinding": {
                        "prefix": "-T"
                    },
                    "id": "#nhmmer.cwl/bitscore_threshold"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "format": "http://edamontology.org/format_1370",
                    "id": "#nhmmer.cwl/query"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#nhmmer.cwl/sequences"
                }
            ],
            "baseCommand": [
                "nhmmer"
            ],
            "arguments": [
                "--tblout",
                "per_target_summary.txt",
                {
                    "valueFrom": "$(runtime.cores)",
                    "prefix": "--cpu"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "per_target_summary.txt"
                    },
                    "id": "#nhmmer.cwl/per_target_summary"
                }
            ],
            "id": "#nhmmer.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "doc": "reformats FASTA. single line sequence, adds 'length=' to header\ndrops seqs with identical IDs (up until the first `/`)\n",
            "requirements": [
                {
                    "coresMax": 1,
                    "ramMin": 1024,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#oneLineFasta.cwl/minimum_length"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#oneLineFasta.cwl/sequences"
                }
            ],
            "baseCommand": "oneLineFasta.py",
            "arguments": [
                {
                    "valueFrom": "$(inputs.sequences.basename)_reformatted.fasta",
                    "position": 2
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "outputBinding": {
                        "glob": "$(inputs.sequences.basename)_reformatted.fasta"
                    },
                    "id": "#oneLineFasta.cwl/reformatted_sequences"
                }
            ],
            "id": "#oneLineFasta.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "gather stats from ORF caller",
            "requirements": [
                {
                    "coresMax": 1,
                    "ramMin": 1024,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_007173"
                            ],
                            "version": [
                                "1.65",
                                "1.66",
                                "1.69"
                            ],
                            "package": "biopython"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "streamable": true,
                    "format": "http://edamontology.org/format_1929",
                    "id": "#orf_stats.cwl/orfs"
                }
            ],
            "baseCommand": "python",
            "arguments": [
                {
                    "prefix": "-c",
                    "valueFrom": "from __future__ import print_function\nimport re\nimport json\nfrom Bio import SeqIO\naccessionPattern = re.compile(\"(\\\\S+)_\\\\d+_\\\\d+_[+-]\")\nnumberOrfs = 0\nreadsWithOrf = set()\nfor record in SeqIO.parse(\"$(inputs.orfs.path)\", \"fasta\"):\n    readAccessionMatch = re.match(accessionPattern, record.id)\n    readAccession = readAccessionMatch.group(1)\n    readsWithOrf.add(readAccession)\n    numberOrfs += 1\nnumberReadsWithOrf = len(readsWithOrf)\nwith open(\"reads.json\", \"w\") as readsFile:\n    json.dump(list(readsWithOrf), readsFile)\nprint(json.dumps({\n  \"numberReadsWithOrf\": numberReadsWithOrf,\n  \"numberOrfs\": numberOrfs,\n  \"readsWithOrf\":{\n      \"class\": \"File\",\n      \"format\": \"https://www.iana.org/assignments/media-types/application/json\",\n      \"path\": \"$(runtime.outdir)/reads.json\" } }))\n"
                }
            ],
            "stdout": "cwl.output.json",
            "outputs": [
                {
                    "type": "int",
                    "id": "#orf_stats.cwl/numberOrfs"
                },
                {
                    "type": "int",
                    "id": "#orf_stats.cwl/numberReadsWithOrf"
                },
                {
                    "type": "File",
                    "streamable": true,
                    "format": "https://www.iana.org/assignments/media-types/application/json",
                    "id": "#orf_stats.cwl/readsWithOrf"
                }
            ],
            "id": "#orf_stats.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "prepend a string + an underscore to all headers in a FASTA sequence file",
            "requirements": [
                {
                    "coresMax": 1,
                    "ramMin": 100,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#prepend_header.cwl/label"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "streamable": true,
                    "id": "#prepend_header.cwl/sequences"
                }
            ],
            "stdin": "$(inputs.sequences.path)",
            "baseCommand": "sed",
            "arguments": [
                "s/^>/>$(inputs.label)_/"
            ],
            "stdout": "$(inputs.sequences.basename).labeled.fasta",
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "id": "#prepend_header.cwl/labeled_sequences",
                    "outputBinding": {
                        "glob": "$(inputs.sequences.basename).labeled.fasta"
                    }
                }
            ],
            "id": "#prepend_header.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "Post QC-ed input analysis of sequence file",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMax": 1,
                    "ramMin": 1024,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "inputBinding": {
                        "prefix": "-i"
                    },
                    "id": "#qc-stats.cwl/QCed_reads"
                },
                {
                    "label": "Prefix for the files associated with GC distribution",
                    "type": "string",
                    "default": "GC-distribution.out",
                    "inputBinding": {
                        "prefix": "-g"
                    },
                    "id": "#qc-stats.cwl/gc_sum"
                },
                {
                    "label": "Prefix for the files assocaited with sequence length distribution",
                    "type": "string",
                    "default": "seq-length.out",
                    "inputBinding": {
                        "prefix": "-l"
                    },
                    "id": "#qc-stats.cwl/length_sum"
                },
                {
                    "label": "Maximum number of sequences to sub-sample",
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 2000000,
                    "inputBinding": {
                        "prefix": "-m"
                    },
                    "id": "#qc-stats.cwl/max_seq"
                },
                {
                    "label": "Prefix for the files associated with nucleotide distribution",
                    "type": "string",
                    "default": "nucleotide-distribution.out",
                    "inputBinding": {
                        "prefix": "-d"
                    },
                    "id": "#qc-stats.cwl/nucleotide_distribution"
                },
                {
                    "label": "File names for summary of sequences, e.g. number, min/max length etc.",
                    "type": "string",
                    "default": "summary.out",
                    "inputBinding": {
                        "prefix": "-o"
                    },
                    "id": "#qc-stats.cwl/summary"
                }
            ],
            "baseCommand": [
                "MGRAST_base.py"
            ],
            "outputs": [
                {
                    "label": "Contains the binned GC distribution, real numbers",
                    "type": "File",
                    "format": "https://www.iana.org/assignments/media-types/text/tab-separated-values",
                    "outputBinding": {
                        "glob": "$(inputs.gc_sum)_bin"
                    },
                    "id": "#qc-stats.cwl/gc_sum_bin"
                },
                {
                    "label": "Contains all GC fractsions observed and sequence counts",
                    "type": "File",
                    "format": "https://www.iana.org/assignments/media-types/text/tab-separated-values",
                    "outputBinding": {
                        "glob": "$(inputs.gc_sum)"
                    },
                    "id": "#qc-stats.cwl/gc_sum_out"
                },
                {
                    "label": "Contains the binned GC distribution, percentage",
                    "type": "File",
                    "format": "https://www.iana.org/assignments/media-types/text/tab-separated-values",
                    "outputBinding": {
                        "glob": "$(inputs.gc_sum)_pcbin"
                    },
                    "id": "#qc-stats.cwl/gc_sum_pcbin"
                },
                {
                    "label": "Contains the normalised fraction of nucleotides on the sequences",
                    "type": "File",
                    "format": "https://www.iana.org/assignments/media-types/text/tab-separated-values",
                    "outputBinding": {
                        "glob": "$(inputs.nucleotide_distribution)"
                    },
                    "id": "#qc-stats.cwl/nucleotide_distribution_out"
                },
                {
                    "label": "Contains the binned length distribution, real numbers",
                    "type": "File",
                    "format": "https://www.iana.org/assignments/media-types/text/tab-separated-values",
                    "outputBinding": {
                        "glob": "$(inputs.length_sum)_bin"
                    },
                    "id": "#qc-stats.cwl/seq_length_bin"
                },
                {
                    "label": "Contains all the lengths observed and frequencies",
                    "type": "File",
                    "format": "https://www.iana.org/assignments/media-types/text/tab-separated-values",
                    "outputBinding": {
                        "glob": "$(inputs.length_sum)"
                    },
                    "id": "#qc-stats.cwl/seq_length_out"
                },
                {
                    "label": "Contains the binned length distribution expressed as percentage",
                    "type": "File",
                    "format": "https://www.iana.org/assignments/media-types/text/tab-separated-values",
                    "outputBinding": {
                        "glob": "$(inputs.length_sum)_pcbin"
                    },
                    "id": "#qc-stats.cwl/seq_length_pcbin"
                },
                {
                    "label": "Contains the summary statistics for the input sequence file",
                    "type": "File",
                    "format": "https://www.iana.org/assignments/media-types/text/plain",
                    "outputBinding": {
                        "glob": "$(inputs.summary)"
                    },
                    "id": "#qc-stats.cwl/summary_out"
                }
            ],
            "id": "#qc-stats.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "coresMax": 1,
                    "ramMin": 1024,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_008249"
                            ],
                            "version": [
                                "1.9.1"
                            ],
                            "package": "qiime"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "doc": "A list of tips (one tip per line) or sequence identifiers (tab-delimited\nlines with a seq identifier in the first field) which should be retained \n",
                    "inputBinding": {
                        "prefix": "--tips_fp=",
                        "separate": false
                    },
                    "id": "#qiime-filter_tree.cwl/tips_or_seqids_to_retain"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--input_tree_filepath=",
                        "separate": false
                    },
                    "id": "#qiime-filter_tree.cwl/tree"
                }
            ],
            "baseCommand": "filter_tree.py",
            "arguments": [
                {
                    "valueFrom": "pruned.tree",
                    "prefix": "--output_tree_filepath=",
                    "separate": false
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "pruned.tree"
                    },
                    "id": "#qiime-filter_tree.cwl/pruned_tree"
                }
            ],
            "id": "#qiime-filter_tree.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "coresMax": 1,
                    "ramMin": 1024,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_008249"
                            ],
                            "version": [
                                "1.9.1"
                            ],
                            "package": "qiime"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "inputBinding": {
                        "prefix": "--input_fp"
                    },
                    "id": "#qiime-pick_closed_reference_otus.cwl/sequences"
                }
            ],
            "baseCommand": "pick_closed_reference_otus.py",
            "arguments": [
                {
                    "valueFrom": "$(runtime.outdir)",
                    "prefix": "--output_dir"
                },
                "--force"
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "log_*.txt"
                    },
                    "id": "#qiime-pick_closed_reference_otus.cwl/log"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3746",
                    "outputBinding": {
                        "glob": "otu_table.biom"
                    },
                    "id": "#qiime-pick_closed_reference_otus.cwl/otu_table"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "97_otus.tree"
                    },
                    "id": "#qiime-pick_closed_reference_otus.cwl/otus_tree"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "uclust_ref_picked_otus/*_clusters.uc"
                    },
                    "id": "#qiime-pick_closed_reference_otus.cwl/sequences-filtered_clusters"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "uclust_ref_picked_otus/*_failures.txt"
                    },
                    "id": "#qiime-pick_closed_reference_otus.cwl/sequences-filtered_failures"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "uclust_ref_picked_otus/*_otus.txt"
                    },
                    "id": "#qiime-pick_closed_reference_otus.cwl/sequences-filtered_otus"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "uclust_ref_picked_otus/*_otus.log"
                    },
                    "id": "#qiime-pick_closed_reference_otus.cwl/sequences-filtered_otus_log"
                }
            ],
            "id": "#qiime-pick_closed_reference_otus.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "Workflow",
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": ".ssi",
                    "format": "http://edamontology.org/format_1929",
                    "id": "#rRNA_selection.cwl/indexed_sequences"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1370",
                    "label": "rRNA protein model to search with",
                    "id": "#rRNA_selection.cwl/model"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#rRNA_selection.cwl/hmmsearch/per_domain_summary",
                    "id": "#rRNA_selection.cwl/hmmer_search_results"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "outputSource": "#rRNA_selection.cwl/sort_matches/rev_sorted_sequences",
                    "id": "#rRNA_selection.cwl/matching_sequences"
                }
            ],
            "steps": [
                {
                    "run": "#extract_coord_lines.cwl",
                    "in": [
                        {
                            "source": "#rRNA_selection.cwl/hmmsearch/per_domain_summary",
                            "id": "#rRNA_selection.cwl/extract_coord_lines/summary"
                        }
                    ],
                    "out": [
                        "#rRNA_selection.cwl/extract_coord_lines/coord_lines"
                    ],
                    "id": "#rRNA_selection.cwl/extract_coord_lines"
                },
                {
                    "run": {
                        "id": "#rRNA_selection.cwl/extract_coordinates/extract_coordinates",
                        "class": "CommandLineTool",
                        "inputs": [
                            {
                                "type": "File",
                                "inputBinding": {
                                    "position": 1
                                },
                                "streamable": true,
                                "doc": "The required columns are as follows:\n(1) target name: The name of the target sequence or profile.\n(18) from (ali coord): The start of the MEA alignment of this\n     domain with respect to the sequence, numbered 1..L for a\n     sequence of L residues.\n(19) to (ali coord): The end of the MEA alignment of this domain\n     with respect to the sequence, numbered 1..L for a sequence of\n     L residues.\n",
                                "id": "#rRNA_selection.cwl/extract_coordinates/extract_coordinates/coordinate_lines"
                            }
                        ],
                        "baseCommand": [
                            "awk",
                            "{print $1\"/\"$18\"-\"$19\" \"$18\" \"$19\" \"$1}"
                        ],
                        "stdout": "$(inputs.coordinate_lines.nameroot).names_and_coords",
                        "outputs": [
                            {
                                "type": "File",
                                "id": "#rRNA_selection.cwl/extract_coordinates/extract_coordinates/formatted_names_and_coords",
                                "outputBinding": {
                                    "glob": "$(inputs.coordinate_lines.nameroot).names_and_coords"
                                }
                            }
                        ]
                    },
                    "in": [
                        {
                            "source": "#rRNA_selection.cwl/extract_coord_lines/coord_lines",
                            "id": "#rRNA_selection.cwl/extract_coordinates/coordinate_lines"
                        }
                    ],
                    "out": [
                        "#rRNA_selection.cwl/extract_coordinates/formatted_names_and_coords"
                    ],
                    "id": "#rRNA_selection.cwl/extract_coordinates"
                },
                {
                    "run": "#esl-sfetch-manyseqs.cwl",
                    "in": [
                        {
                            "source": "#rRNA_selection.cwl/indexed_sequences",
                            "id": "#rRNA_selection.cwl/fetch_aligned_sequences/indexed_sequences"
                        },
                        {
                            "source": "#rRNA_selection.cwl/extract_coordinates/formatted_names_and_coords",
                            "id": "#rRNA_selection.cwl/fetch_aligned_sequences/names"
                        },
                        {
                            "default": true,
                            "id": "#rRNA_selection.cwl/fetch_aligned_sequences/names_contain_subseq_coords"
                        }
                    ],
                    "out": [
                        "#rRNA_selection.cwl/fetch_aligned_sequences/sequences"
                    ],
                    "id": "#rRNA_selection.cwl/fetch_aligned_sequences"
                },
                {
                    "run": "#hmmsearch.cwl",
                    "in": [
                        {
                            "default": "1.0E-5",
                            "id": "#rRNA_selection.cwl/hmmsearch/e_threshold"
                        },
                        {
                            "source": "#rRNA_selection.cwl/model",
                            "id": "#rRNA_selection.cwl/hmmsearch/hmm_profiles"
                        },
                        {
                            "source": "#rRNA_selection.cwl/indexed_sequences",
                            "id": "#rRNA_selection.cwl/hmmsearch/sequence_query"
                        }
                    ],
                    "out": [
                        "#rRNA_selection.cwl/hmmsearch/per_domain_summary"
                    ],
                    "id": "#rRNA_selection.cwl/hmmsearch"
                },
                {
                    "run": "#oneLineFasta.cwl",
                    "in": [
                        {
                            "default": 80,
                            "id": "#rRNA_selection.cwl/reformat_matches/minimum_length"
                        },
                        {
                            "source": "#rRNA_selection.cwl/fetch_aligned_sequences/sequences",
                            "id": "#rRNA_selection.cwl/reformat_matches/sequences"
                        }
                    ],
                    "out": [
                        "#rRNA_selection.cwl/reformat_matches/reformatted_sequences"
                    ],
                    "id": "#rRNA_selection.cwl/reformat_matches"
                },
                {
                    "run": "#RevReadSort.cwl",
                    "in": [
                        {
                            "source": "#rRNA_selection.cwl/reformat_matches/reformatted_sequences",
                            "id": "#rRNA_selection.cwl/sort_matches/sequences"
                        }
                    ],
                    "out": [
                        "#rRNA_selection.cwl/sort_matches/rev_sorted_sequences"
                    ],
                    "id": "#rRNA_selection.cwl/sort_matches"
                }
            ],
            "id": "#rRNA_selection.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "coresMax": 1,
                    "ramMin": 100,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "packages": [
                        {
                            "specs": null,
                            "package": "gunzip"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#seqprep-merge.cwl/forward_unmerged_reads"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#seqprep-merge.cwl/merged_reads"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#seqprep-merge.cwl/reverse_unmerged_reads"
                }
            ],
            "baseCommand": [
                "gunzip",
                "-c"
            ],
            "stdout": "merged_with_unmerged_reads",
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "id": "#seqprep-merge.cwl/merged_with_unmerged_reads",
                    "outputBinding": {
                        "glob": "merged_with_unmerged_reads"
                    }
                }
            ],
            "id": "#seqprep-merge.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "coresMax": 1,
                    "ramMin": 1024,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_013004"
                            ],
                            "version": [
                                "1.1"
                            ],
                            "package": "seqprep"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "label": "first read input fastq",
                    "inputBinding": {
                        "prefix": "-f"
                    },
                    "id": "#seqprep.cwl/forward_reads"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "label": "second read input fastq",
                    "inputBinding": {
                        "prefix": "-r"
                    },
                    "id": "#seqprep.cwl/reverse_reads"
                }
            ],
            "baseCommand": "SeqPrep",
            "arguments": [
                "-1",
                "forward_unmerged.fastq.gz",
                "-2",
                "reverse_unmerged.fastq.gz",
                "-s",
                "merged.fastq.gz"
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "outputBinding": {
                        "glob": "forward_unmerged.fastq.gz"
                    },
                    "id": "#seqprep.cwl/forward_unmerged_reads"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "outputBinding": {
                        "glob": "merged.fastq.gz"
                    },
                    "id": "#seqprep.cwl/merged_reads"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "outputBinding": {
                        "glob": "reverse_unmerged.fastq.gz"
                    },
                    "id": "#seqprep.cwl/reverse_unmerged_reads"
                }
            ],
            "id": "#seqprep.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "gather stats from InterProScan",
            "requirements": [
                {
                    "coresMax": 1,
                    "ramMin": 1024,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "packages": [
                        {
                            "package": "python"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "int",
                    "id": "#summary.cwl/CDS_with_match"
                },
                {
                    "type": "int",
                    "id": "#summary.cwl/IPS_matches"
                },
                {
                    "type": "int",
                    "id": "#summary.cwl/initial_filtered_count"
                },
                {
                    "type": "int",
                    "id": "#summary.cwl/predicted_CDS_count"
                },
                {
                    "type": "int",
                    "id": "#summary.cwl/reads_with_match"
                },
                {
                    "type": "int",
                    "id": "#summary.cwl/reads_with_orf"
                },
                {
                    "type": "int",
                    "id": "#summary.cwl/rna_count"
                },
                {
                    "type": "int",
                    "id": "#summary.cwl/submitted_count"
                }
            ],
            "baseCommand": "python",
            "arguments": [
                {
                    "prefix": "-c",
                    "valueFrom": "from __future__ import print_function\nprint(\"Submitted nucleotide sequences\\\\t$(inputs.submitted_count)\")\nprint(\"Nucleotide sequences after trimming and quality \"\n      \"filtering\\\\t$(inputs.initial_filtered_count)\")\nprint(\"Nucleotide sequences with predicted CDS\\\\t$(inputs.reads_with_orf)\")\nprint(\"Nucleotide sequences with predicted RNA\\\\t$(inputs.rna_count)\")\nprint(\"Nucleotide sequences with InterProScan match\\\\t$(inputs.reads_with_match)\")\nprint(\"Predicted CDS\\\\t$(inputs.predicted_CDS_count)\")\nprint(\"Predicted CDS with InterProScan match\\\\t$(inputs.CDS_with_match)\")\nprint(\"Total InterProScan matches\\\\t$(inputs.IPS_matches)\")\n"
                }
            ],
            "stdout": "summary",
            "outputs": [
                {
                    "type": "File",
                    "id": "#summary.cwl/summary",
                    "outputBinding": {
                        "glob": "summary"
                    }
                }
            ],
            "id": "#summary.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "Workflow",
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": ".ssi",
                    "format": "http://edamontology.org/format_1929",
                    "id": "#tRNA_selection.cwl/indexed_sequences"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1370",
                    "label": "tRNA model to search with",
                    "id": "#tRNA_selection.cwl/model"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#tRNA_selection.cwl/nhmmer/per_target_summary",
                    "id": "#tRNA_selection.cwl/hmmer_search_results"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "outputSource": "#tRNA_selection.cwl/sort_matches/rev_sorted_sequences",
                    "id": "#tRNA_selection.cwl/matching_sequences"
                }
            ],
            "steps": [
                {
                    "run": "#extract_coord_lines.cwl",
                    "in": [
                        {
                            "source": "#tRNA_selection.cwl/nhmmer/per_target_summary",
                            "id": "#tRNA_selection.cwl/extract_coord_lines/summary"
                        }
                    ],
                    "out": [
                        "#tRNA_selection.cwl/extract_coord_lines/coord_lines"
                    ],
                    "id": "#tRNA_selection.cwl/extract_coord_lines"
                },
                {
                    "run": {
                        "id": "#tRNA_selection.cwl/extract_coordinates/extract_coordinates",
                        "class": "CommandLineTool",
                        "inputs": [
                            {
                                "type": "File",
                                "inputBinding": {
                                    "position": 1
                                },
                                "streamable": true,
                                "doc": "The required columns are as follows:\n(1) target name: The name of the target sequence or profile.\n(7) alifrom: The position in the target sequence at which the hit\n             starts\n(8) ali to: The position in the target sequence at which the hit\n            ends.\n",
                                "id": "#tRNA_selection.cwl/extract_coordinates/extract_coordinates/coordinate_lines"
                            }
                        ],
                        "baseCommand": [
                            "awk",
                            "{print $1\"/\"$7\"-\"$8\" \"$7\" \"$8\" \"$1}"
                        ],
                        "stdout": "formatted_names_and_coords",
                        "outputs": [
                            {
                                "type": "File",
                                "id": "#tRNA_selection.cwl/extract_coordinates/extract_coordinates/formatted_names_and_coords",
                                "outputBinding": {
                                    "glob": "formatted_names_and_coords"
                                }
                            }
                        ]
                    },
                    "in": [
                        {
                            "source": "#tRNA_selection.cwl/extract_coord_lines/coord_lines",
                            "id": "#tRNA_selection.cwl/extract_coordinates/coordinate_lines"
                        }
                    ],
                    "out": [
                        "#tRNA_selection.cwl/extract_coordinates/formatted_names_and_coords"
                    ],
                    "id": "#tRNA_selection.cwl/extract_coordinates"
                },
                {
                    "run": "#esl-sfetch-manyseqs.cwl",
                    "in": [
                        {
                            "source": "#tRNA_selection.cwl/indexed_sequences",
                            "id": "#tRNA_selection.cwl/fetch_aligned_sequences/indexed_sequences"
                        },
                        {
                            "source": "#tRNA_selection.cwl/extract_coordinates/formatted_names_and_coords",
                            "id": "#tRNA_selection.cwl/fetch_aligned_sequences/names"
                        },
                        {
                            "default": true,
                            "id": "#tRNA_selection.cwl/fetch_aligned_sequences/names_contain_subseq_coords"
                        }
                    ],
                    "out": [
                        "#tRNA_selection.cwl/fetch_aligned_sequences/sequences"
                    ],
                    "id": "#tRNA_selection.cwl/fetch_aligned_sequences"
                },
                {
                    "run": "#nhmmer.cwl",
                    "in": [
                        {
                            "default": 20,
                            "id": "#tRNA_selection.cwl/nhmmer/bitscore_threshold"
                        },
                        {
                            "source": "#tRNA_selection.cwl/model",
                            "id": "#tRNA_selection.cwl/nhmmer/query"
                        },
                        {
                            "source": "#tRNA_selection.cwl/indexed_sequences",
                            "id": "#tRNA_selection.cwl/nhmmer/sequences"
                        }
                    ],
                    "out": [
                        "#tRNA_selection.cwl/nhmmer/per_target_summary"
                    ],
                    "id": "#tRNA_selection.cwl/nhmmer"
                },
                {
                    "run": "#oneLineFasta.cwl",
                    "in": [
                        {
                            "default": 30,
                            "id": "#tRNA_selection.cwl/reformat_matches/minimum_length"
                        },
                        {
                            "source": "#tRNA_selection.cwl/fetch_aligned_sequences/sequences",
                            "id": "#tRNA_selection.cwl/reformat_matches/sequences"
                        }
                    ],
                    "out": [
                        "#tRNA_selection.cwl/reformat_matches/reformatted_sequences"
                    ],
                    "id": "#tRNA_selection.cwl/reformat_matches"
                },
                {
                    "run": "#RevReadSort.cwl",
                    "in": [
                        {
                            "source": "#tRNA_selection.cwl/reformat_matches/reformatted_sequences",
                            "id": "#tRNA_selection.cwl/sort_matches/sequences"
                        }
                    ],
                    "out": [
                        "#tRNA_selection.cwl/sort_matches/rev_sorted_sequences"
                    ],
                    "id": "#tRNA_selection.cwl/sort_matches"
                }
            ],
            "id": "#tRNA_selection.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_011848"
                            ],
                            "version": [
                                "0.32",
                                "0.35",
                                "0.36"
                            ],
                            "package": "trimmomatic"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "ramMin": 10240,
                    "coresMin": 8,
                    "class": "ResourceRequirement"
                },
                {
                    "types": [
                        {
                            "type": "enum",
                            "name": "#trimmomatic-end_mode.yaml/end_mode",
                            "symbols": [
                                "#trimmomatic-end_mode.yaml/end_mode/SE",
                                "#trimmomatic-end_mode.yaml/end_mode/PE"
                            ]
                        },
                        {
                            "type": "record",
                            "name": "#trimmomatic-sliding_window.yaml/slidingWindow",
                            "fields": [
                                {
                                    "name": "#trimmomatic-sliding_window.yaml/slidingWindow/windowSize",
                                    "type": "int"
                                },
                                {
                                    "name": "#trimmomatic-sliding_window.yaml/slidingWindow/requiredQuality",
                                    "type": "int"
                                }
                            ]
                        },
                        {
                            "type": "enum",
                            "name": "#trimmomatic-phred.yaml/phred",
                            "symbols": [
                                "#trimmomatic-phred.yaml/phred/64",
                                "#trimmomatic-phred.yaml/phred/33"
                            ]
                        },
                        {
                            "type": "record",
                            "name": "#trimmomatic-illumina_clipping.yaml/illuminaClipping",
                            "fields": [
                                {
                                    "name": "#trimmomatic-illumina_clipping.yaml/illuminaClipping/adapters",
                                    "type": "File",
                                    "doc": "FASTA file containing adapters, PCR sequences, etc. It is used to search\nfor and remove these sequences in the input FASTQ file(s)\n"
                                },
                                {
                                    "name": "#trimmomatic-illumina_clipping.yaml/illuminaClipping/seedMismatches",
                                    "type": "int",
                                    "doc": "specifies the maximum mismatch count which will still allow a full match\nto be performed\n"
                                },
                                {
                                    "name": "#trimmomatic-illumina_clipping.yaml/illuminaClipping/palindromeClipThreshold",
                                    "type": "int",
                                    "doc": "specifies how accurate the match between the two 'adapter ligated' reads\nmust be for PE palindrome read alignment.\n"
                                },
                                {
                                    "name": "#trimmomatic-illumina_clipping.yaml/illuminaClipping/simpleClipThreshold",
                                    "type": "int",
                                    "doc": "specifies how accurate the match between any adapter etc. sequence must\nbe against a read\n"
                                },
                                {
                                    "name": "#trimmomatic-illumina_clipping.yaml/illuminaClipping/minAdapterLength",
                                    "type": [
                                        "null",
                                        "int"
                                    ],
                                    "doc": "In addition to the alignment score, palindrome mode can verify that a\nminimum length of adapter has been detected. If unspecified, this\ndefaults to 8 bases, for historical reasons. However, since palindrome\nmode has a very low false positive rate, this can be safely reduced, even\ndown to 1, to allow shorter adapter fragments to be removed.\n"
                                },
                                {
                                    "name": "#trimmomatic-illumina_clipping.yaml/illuminaClipping/keepBothReads",
                                    "type": "boolean",
                                    "doc": "After read-though has been detected by palindrome mode, and the adapter\nsequence removed, the reverse read contains the same sequence information\nas the forward read, albeit in reverse complement. For this reason, the\ndefault behaviour is to entirely drop the reverse read. By specifying\n\"true\" for this parameter, the reverse read will also be retained, which\nmay be useful e.g. if the downstream tools cannot handle a combination of\npaired and unpaired reads.  \n"
                                }
                            ]
                        },
                        {
                            "type": "record",
                            "name": "#trimmomatic-max_info.yaml/maxinfo",
                            "fields": [
                                {
                                    "name": "#trimmomatic-max_info.yaml/maxinfo/targetLength",
                                    "type": "int"
                                },
                                {
                                    "name": "#trimmomatic-max_info.yaml/maxinfo/strictness",
                                    "type": "int"
                                }
                            ]
                        }
                    ],
                    "class": "SchemaDefRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 101,
                        "prefix": "AVGQUAL:",
                        "separate": false
                    },
                    "doc": "Drop the read if the average quality is below the specified level\n",
                    "id": "#trimmomatic.cwl/avgqual"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 13,
                        "prefix": "CROP:",
                        "separate": false
                    },
                    "doc": "Removes bases regardless of quality from the end of the read, so that the\nread has maximally the specified length after this step has been\nperformed. Steps performed after CROP might of course further shorten the\nread. The value is the number of bases to keep, from the start of the read.\n",
                    "id": "#trimmomatic.cwl/crop"
                },
                {
                    "type": "#trimmomatic-end_mode.yaml/end_mode",
                    "inputBinding": {
                        "position": 3
                    },
                    "doc": "Single End (SE) or Paired End (PE) mode\n",
                    "id": "#trimmomatic.cwl/end_mode"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 13,
                        "prefix": "HEADCROP:",
                        "separate": false
                    },
                    "doc": "Removes the specified number of bases, regardless of quality, from the\nbeginning of the read.\nThe numbser specified is the number of bases to keep, from the start of\nthe read.\n",
                    "id": "#trimmomatic.cwl/headcrop"
                },
                {
                    "type": [
                        "null",
                        "#trimmomatic-illumina_clipping.yaml/illuminaClipping"
                    ],
                    "inputBinding": {
                        "valueFrom": "${ if ( self ) {\n     return \"ILLUMINACLIP:\" + inputs.illuminaClip.adapters.path + \":\"\n       + self.seedMismatches + \":\" + self.palindromeClipThreshold + \":\"\n       + self.simpleClipThreshold + \":\" + self.minAdapterLength + \":\"\n       + self.keepBothReads;\n   } else {\n     return self;\n   }\n }\n",
                        "position": 11
                    },
                    "doc": "Cut adapter and other illumina-specific sequences from the read.",
                    "id": "#trimmomatic.cwl/illuminaClip"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "shellQuote": false
                    },
                    "doc": "JVM arguments should be a quoted, space separated list\n(e.g. \"-Xms128m -Xmx512m\")\n",
                    "id": "#trimmomatic.cwl/java_opts"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 14,
                        "prefix": "LEADING:",
                        "separate": false
                    },
                    "doc": "Remove low quality bases from the beginning. As long as a base has a\nvalue below this threshold the base is removed and the next base will be\ninvestigated.\n",
                    "id": "#trimmomatic.cwl/leading"
                },
                {
                    "type": [
                        "null",
                        "#trimmomatic-max_info.yaml/maxinfo"
                    ],
                    "inputBinding": {
                        "position": 15,
                        "valueFrom": "${ if ( self ) {\n     return \"MAXINFO:\" + self.targetLength + \":\" + self.strictness;\n   } else {\n     return self;\n   }\n }\n"
                    },
                    "doc": "Performs an adaptive quality trim, balancing the benefits of retaining\nlonger reads against the costs of retaining bases with errors.\n<targetLength>: This specifies the read length which is likely to allow\nthe location of the read within the target sequence to be determined.\n<strictness>: This value, which should be set between 0 and 1, specifies\nthe balance between preserving as much read length as possible vs.\nremoval of incorrect bases. A low value of this parameter (<0.2) favours\nlonger reads, while a high value (>0.8) favours read correctness.\n",
                    "id": "#trimmomatic.cwl/maxinfo"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 100,
                        "prefix": "MINLEN:",
                        "separate": false
                    },
                    "doc": "This module removes reads that fall below the specified minimal length.\nIf required, it should normally be after all other processing steps.\nReads removed by this step will be counted and included in the \"dropped\nreads\" count presented in the trimmomatic summary.\n",
                    "id": "#trimmomatic.cwl/minlen"
                },
                {
                    "type": [
                        "null",
                        "#trimmomatic-phred.yaml/phred"
                    ],
                    "inputBinding": {
                        "prefix": "-phred",
                        "separate": false,
                        "position": 4
                    },
                    "doc": "\"33\" or \"64\" specifies the base quality encoding. Default: 64\n",
                    "id": "#trimmomatic.cwl/phred"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "inputBinding": {
                        "position": 5
                    },
                    "doc": "FASTQ file of reads (R1 reads in Paired End mode)",
                    "id": "#trimmomatic.cwl/reads1"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_1930",
                    "inputBinding": {
                        "position": 6
                    },
                    "doc": "FASTQ file of R2 reads in Paired End mode",
                    "id": "#trimmomatic.cwl/reads2"
                },
                {
                    "type": [
                        "null",
                        "#trimmomatic-sliding_window.yaml/slidingWindow"
                    ],
                    "inputBinding": {
                        "position": 15,
                        "valueFrom": "${ if ( self ) {\n     return \"SLIDINGWINDOW:\" + self.windowSize + \":\"\n       + self.requiredQuality;\n   } else {\n     return self;\n   }\n }\n"
                    },
                    "doc": "Perform a sliding window trimming, cutting once the average quality\nwithin the window falls below a threshold. By considering multiple\nbases, a single poor quality base will not cause the removal of high\nquality data later in the read.\n<windowSize> specifies the number of bases to average across\n<requiredQuality> specifies the average quality required\n",
                    "id": "#trimmomatic.cwl/slidingwindow"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 12,
                        "prefix": "TOPHRED33",
                        "separate": false
                    },
                    "doc": "This (re)encodes the quality part of the FASTQ file to base 33.",
                    "id": "#trimmomatic.cwl/tophred33"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 12,
                        "prefix": "TOPHRED64",
                        "separate": false
                    },
                    "doc": "This (re)encodes the quality part of the FASTQ file to base 64.",
                    "id": "#trimmomatic.cwl/tophred64"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 14,
                        "prefix": "TRAILING:",
                        "separate": false
                    },
                    "doc": "Remove low quality bases from the end. As long as a base has a value\nbelow this threshold the base is removed and the next base (which as\ntrimmomatic is starting from the 3' prime end would be base preceding\nthe just removed base) will be investigated. This approach can be used\nremoving the special Illumina \"low quality segment\" regions (which are\nmarked with quality score of 2), but we recommend Sliding Window or\nMaxInfo instead\n",
                    "id": "#trimmomatic.cwl/trailing"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "trim.log"
                    },
                    "label": "Trimmomatic log",
                    "doc": "log of all read trimmings, indicating the following details:\n  the read name\n  the surviving sequence length\n  the location of the first surviving base, aka. the amount trimmed from the start\n  the location of the last surviving base in the original read\n  the amount trimmed from the end\n",
                    "id": "#trimmomatic.cwl/output_log"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "outputBinding": {
                        "glob": "$(inputs.reads1.nameroot).trimmed.fastq"
                    },
                    "id": "#trimmomatic.cwl/reads1_trimmed"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_1930",
                    "outputBinding": {
                        "glob": "$(inputs.reads1.nameroot).unpaired.trimmed.fastq"
                    },
                    "id": "#trimmomatic.cwl/reads1_trimmed_unpaired"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_1930",
                    "outputBinding": {
                        "glob": "${ if (inputs.reads2 ) {\n     return inputs.reads2.nameroot + '.trimmed.fastq';\n   } else {\n     return null;\n   }\n }\n"
                    },
                    "id": "#trimmomatic.cwl/reads2_trimmed_paired"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_1930",
                    "outputBinding": {
                        "glob": "${ if (inputs.reads2 ) {\n     return inputs.reads2.nameroot + '.unpaired.trimmed.fastq';\n   } else {\n     return null;\n   }\n }\n"
                    },
                    "id": "#trimmomatic.cwl/reads2_trimmed_unpaired"
                }
            ],
            "baseCommand": [
                "java",
                "org.usadellab.trimmomatic.Trimmomatic"
            ],
            "arguments": [
                {
                    "valueFrom": "trim.log",
                    "prefix": "-trimlog",
                    "position": 4
                },
                {
                    "valueFrom": "$(runtime.cores)",
                    "position": 4,
                    "prefix": "-threads"
                },
                {
                    "valueFrom": "$(inputs.reads1.nameroot).trimmed.fastq",
                    "position": 7
                },
                {
                    "valueFrom": "${\n  if (inputs.end_mode == \"PE\" && inputs.reads2) {\n    return inputs.reads1.nameroot + '.trimmed.unpaired.fastq';\n  } else {\n    return null;\n  }\n}\n",
                    "position": 8
                },
                {
                    "valueFrom": "${\n  if (inputs.end_mode == \"PE\" && inputs.reads2) {\n    return inputs.reads2.nameroot + '.trimmed.fastq';\n  } else {\n    return null;\n  }\n}\n",
                    "position": 9
                },
                {
                    "valueFrom": "${\n  if (inputs.end_mode == \"PE\" && inputs.reads2) {\n    return inputs.reads2.nameroot + '.trimmed.unpaired.fastq';\n  } else {\n    return null;\n  }\n}\n",
                    "position": 10
                }
            ],
            "doc": "Trimmomatic is a fast, multithreaded command line tool that can be used to trim and crop\nIllumina (FASTQ) data as well as to remove adapters. These adapters can pose a real problem\ndepending on the library preparation and downstream application.\nThere are two major modes of the program: Paired end mode and Single end mode. The\npaired end mode will maintain correspondence of read pairs and also use the additional\ninformation contained in paired reads to better find adapter or PCR primer fragments\nintroduced by the library preparation process.\nTrimmomatic works with FASTQ files (using phred + 33 or phred + 64 quality scores,\ndepending on the Illumina pipeline used).\n",
            "id": "#trimmomatic.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "coresMax": 1,
                    "ramMin": 100,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "packages": [
                        {
                            "package": "python"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#update_krona_chart_urls.cwl/krona_chart"
                }
            ],
            "baseCommand": "python",
            "arguments": [
                {
                    "prefix": "-c",
                    "valueFrom": "text = \"\"\nwith open(\"$(inputs.krona_chart.path)\", \"r\") as inFile:\n   text = inFile.read()\nnotFound = r'<script id=\"notfound\">window.onload=function(){document.body.innerHTML=\"Could not get resources from \\\\\"http://krona.sourceforge.net\\\\\".\"}</script>'\ntext = text.replace(notFound, \"\")\noldJavaScriptUrl = \"http://krona.sourceforge.net/src/krona-2.0.js\"\nnewJavaScriptUrl = \"/metagenomics/js/krona-2.0-customized.js\"\ntext = text.replace(oldJavaScriptUrl, newJavaScriptUrl)\noldImageUrlPrefix = \"http://krona.sourceforge.net/img/\"\nnewImageUrlPrefix = \"/metagenomics/img/krona/\"\ntext = text.replace(oldImageUrlPrefix, newImageUrlPrefix)\nwith open(\"$(inputs.krona_chart.nameroot)_fixed.html\", \"w\") as outFile:\n    outFile.write(text)\n"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.krona_chart.nameroot)_fixed.html"
                    },
                    "id": "#update_krona_chart_urls.cwl/fixed_krona_chart"
                }
            ],
            "id": "#update_krona_chart_urls.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "gather stats from InterProScan",
            "requirements": [
                {
                    "coresMax": 1,
                    "ramMin": 10204,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "packages": [
                        {
                            "package": "python"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "streamable": true,
                    "format": "https://www.iana.org/assignments/media-types/application/yaml",
                    "id": "#write_ipr_summary.cwl/ipr_entry_maps"
                }
            ],
            "baseCommand": "python",
            "arguments": [
                {
                    "prefix": "-c",
                    "valueFrom": "from __future__ import print_function\nimport yaml\nipr_maps = yaml.load(open(\"$(inputs.ipr_entry_maps.path)\", \"r\"))\nentry2protein = ipr_maps[\"entry2protein\"]\nentry2name = ipr_maps[\"entry2name\"]\nunsortedEntries = []\nfor item in entry2protein.items():\n    entry = item[0]\n    proteins = item[1]\n    name = entry2name[entry]\n    tuple = (entry, name, len(proteins))\n    unsortedEntries.append(tuple)\nsortedEntries = sorted(unsortedEntries, key=lambda item: item[2])\nsortedEntries.reverse()\nfor entry in sortedEntries:\n    print(\",\".join(['\"' + entry[0], entry[1], str(entry[2]) + '\"']))\n"
                }
            ],
            "stdout": "summary.ipr",
            "outputs": [
                {
                    "type": "File",
                    "id": "#write_ipr_summary.cwl/ipr_summary",
                    "outputBinding": {
                        "glob": "summary.ipr"
                    }
                }
            ],
            "id": "#write_ipr_summary.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "Workflow",
            "label": "Functional analyis of sequences that match the 16S SSU",
            "requirements": [
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "$import": "#biom-convert-table.yaml/table_type"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#16S_taxonomic_analysis.cwl/16S_matches"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#16S_taxonomic_analysis.cwl/convert_otu_counts_to_hdf5/result",
                    "id": "#16S_taxonomic_analysis.cwl/biom_hdf5"
                },
                {
                    "type": "File",
                    "outputSource": "#16S_taxonomic_analysis.cwl/convert_new_biom_to_old_biom/result",
                    "id": "#16S_taxonomic_analysis.cwl/biom_json"
                },
                {
                    "type": "File",
                    "outputSource": "#16S_taxonomic_analysis.cwl/convert_new_biom_to_classic/result",
                    "id": "#16S_taxonomic_analysis.cwl/biom_tsv"
                },
                {
                    "type": "File",
                    "outputSource": "#16S_taxonomic_analysis.cwl/krona_setup/kingdom_counts",
                    "id": "#16S_taxonomic_analysis.cwl/kingdom_counts"
                },
                {
                    "type": "File",
                    "outputSource": "#16S_taxonomic_analysis.cwl/krona_setup/krona_input",
                    "id": "#16S_taxonomic_analysis.cwl/krona_input"
                },
                {
                    "type": "File",
                    "outputSource": "#16S_taxonomic_analysis.cwl/create_otu_text_summary/otu_table_summary",
                    "id": "#16S_taxonomic_analysis.cwl/otu_table_summary"
                },
                {
                    "type": "File",
                    "outputSource": "#16S_taxonomic_analysis.cwl/update_krona_chart_urls/fixed_krona_chart",
                    "id": "#16S_taxonomic_analysis.cwl/otu_visualization"
                },
                {
                    "type": "File",
                    "outputSource": "#16S_taxonomic_analysis.cwl/modify_taxonomy_table/qiime_assigned_taxonomy",
                    "id": "#16S_taxonomic_analysis.cwl/qiime_assigned_taxonomy"
                },
                {
                    "type": "File",
                    "outputSource": "#16S_taxonomic_analysis.cwl/pick_closed_reference_otus/sequences-filtered_clusters",
                    "id": "#16S_taxonomic_analysis.cwl/qiime_sequences-filtered_clusters"
                },
                {
                    "type": "File",
                    "outputSource": "#16S_taxonomic_analysis.cwl/pick_closed_reference_otus/sequences-filtered_otus",
                    "id": "#16S_taxonomic_analysis.cwl/qiime_sequences-filtered_otus"
                },
                {
                    "type": "File",
                    "outputSource": "#16S_taxonomic_analysis.cwl/prune_tree/pruned_tree",
                    "id": "#16S_taxonomic_analysis.cwl/tree"
                }
            ],
            "steps": [
                {
                    "run": "#biom-convert.cwl",
                    "in": [
                        {
                            "source": "#16S_taxonomic_analysis.cwl/pick_closed_reference_otus/otu_table",
                            "id": "#16S_taxonomic_analysis.cwl/convert_new_biom_to_classic/biom"
                        },
                        {
                            "default": "taxonomy",
                            "id": "#16S_taxonomic_analysis.cwl/convert_new_biom_to_classic/header_key"
                        },
                        {
                            "default": "OTU table",
                            "id": "#16S_taxonomic_analysis.cwl/convert_new_biom_to_classic/table_type"
                        },
                        {
                            "default": true,
                            "id": "#16S_taxonomic_analysis.cwl/convert_new_biom_to_classic/tsv"
                        }
                    ],
                    "out": [
                        "#16S_taxonomic_analysis.cwl/convert_new_biom_to_classic/result"
                    ],
                    "id": "#16S_taxonomic_analysis.cwl/convert_new_biom_to_classic"
                },
                {
                    "run": "#biom-convert.cwl",
                    "in": [
                        {
                            "source": "#16S_taxonomic_analysis.cwl/pick_closed_reference_otus/otu_table",
                            "id": "#16S_taxonomic_analysis.cwl/convert_new_biom_to_old_biom/biom"
                        },
                        {
                            "default": true,
                            "id": "#16S_taxonomic_analysis.cwl/convert_new_biom_to_old_biom/json"
                        },
                        {
                            "default": "OTU table",
                            "id": "#16S_taxonomic_analysis.cwl/convert_new_biom_to_old_biom/table_type"
                        }
                    ],
                    "out": [
                        "#16S_taxonomic_analysis.cwl/convert_new_biom_to_old_biom/result"
                    ],
                    "id": "#16S_taxonomic_analysis.cwl/convert_new_biom_to_old_biom"
                },
                {
                    "run": "#biom-convert.cwl",
                    "in": [
                        {
                            "source": "#16S_taxonomic_analysis.cwl/pick_closed_reference_otus/otu_table",
                            "id": "#16S_taxonomic_analysis.cwl/convert_otu_counts_to_hdf5/biom"
                        },
                        {
                            "default": true,
                            "id": "#16S_taxonomic_analysis.cwl/convert_otu_counts_to_hdf5/hdf5"
                        },
                        {
                            "default": "OTU table",
                            "id": "#16S_taxonomic_analysis.cwl/convert_otu_counts_to_hdf5/table_type"
                        }
                    ],
                    "out": [
                        "#16S_taxonomic_analysis.cwl/convert_otu_counts_to_hdf5/result"
                    ],
                    "id": "#16S_taxonomic_analysis.cwl/convert_otu_counts_to_hdf5"
                },
                {
                    "run": "#biom-summarize_table.cwl",
                    "in": [
                        {
                            "source": "#16S_taxonomic_analysis.cwl/pick_closed_reference_otus/otu_table",
                            "id": "#16S_taxonomic_analysis.cwl/create_otu_text_summary/biom"
                        }
                    ],
                    "out": [
                        "#16S_taxonomic_analysis.cwl/create_otu_text_summary/otu_table_summary"
                    ],
                    "id": "#16S_taxonomic_analysis.cwl/create_otu_text_summary"
                },
                {
                    "run": "#extract_observations.cwl",
                    "in": [
                        {
                            "source": "#16S_taxonomic_analysis.cwl/convert_new_biom_to_classic/result",
                            "id": "#16S_taxonomic_analysis.cwl/extract_observations/tsv_otu_table"
                        }
                    ],
                    "out": [
                        "#16S_taxonomic_analysis.cwl/extract_observations/observations"
                    ],
                    "id": "#16S_taxonomic_analysis.cwl/extract_observations"
                },
                {
                    "run": "#krona_setup.cwl",
                    "in": [
                        {
                            "source": "#16S_taxonomic_analysis.cwl/modify_taxonomy_table/qiime_assigned_taxonomy",
                            "id": "#16S_taxonomic_analysis.cwl/krona_setup/qiime_taxonomy"
                        }
                    ],
                    "out": [
                        "#16S_taxonomic_analysis.cwl/krona_setup/krona_input",
                        "#16S_taxonomic_analysis.cwl/krona_setup/kingdom_counts"
                    ],
                    "id": "#16S_taxonomic_analysis.cwl/krona_setup"
                },
                {
                    "run": "#modify_taxonomy_table.cwl",
                    "in": [
                        {
                            "source": "#16S_taxonomic_analysis.cwl/convert_new_biom_to_classic/result",
                            "id": "#16S_taxonomic_analysis.cwl/modify_taxonomy_table/otu_table"
                        },
                        {
                            "source": "#16S_taxonomic_analysis.cwl/pick_closed_reference_otus/sequences-filtered_otus_log",
                            "id": "#16S_taxonomic_analysis.cwl/modify_taxonomy_table/uclust_log"
                        }
                    ],
                    "out": [
                        "#16S_taxonomic_analysis.cwl/modify_taxonomy_table/qiime_assigned_taxonomy"
                    ],
                    "id": "#16S_taxonomic_analysis.cwl/modify_taxonomy_table"
                },
                {
                    "run": "#qiime-pick_closed_reference_otus.cwl",
                    "in": [
                        {
                            "source": "#16S_taxonomic_analysis.cwl/16S_matches",
                            "id": "#16S_taxonomic_analysis.cwl/pick_closed_reference_otus/sequences"
                        }
                    ],
                    "out": [
                        "#16S_taxonomic_analysis.cwl/pick_closed_reference_otus/otu_table",
                        "#16S_taxonomic_analysis.cwl/pick_closed_reference_otus/otus_tree",
                        "#16S_taxonomic_analysis.cwl/pick_closed_reference_otus/sequences-filtered_clusters",
                        "#16S_taxonomic_analysis.cwl/pick_closed_reference_otus/sequences-filtered_otus",
                        "#16S_taxonomic_analysis.cwl/pick_closed_reference_otus/sequences-filtered_otus_log"
                    ],
                    "id": "#16S_taxonomic_analysis.cwl/pick_closed_reference_otus"
                },
                {
                    "run": "#qiime-filter_tree.cwl",
                    "in": [
                        {
                            "source": "#16S_taxonomic_analysis.cwl/extract_observations/observations",
                            "id": "#16S_taxonomic_analysis.cwl/prune_tree/tips_or_seqids_to_retain"
                        },
                        {
                            "source": "#16S_taxonomic_analysis.cwl/pick_closed_reference_otus/otus_tree",
                            "id": "#16S_taxonomic_analysis.cwl/prune_tree/tree"
                        }
                    ],
                    "out": [
                        "#16S_taxonomic_analysis.cwl/prune_tree/pruned_tree"
                    ],
                    "id": "#16S_taxonomic_analysis.cwl/prune_tree"
                },
                {
                    "run": "#update_krona_chart_urls.cwl",
                    "in": [
                        {
                            "source": "#16S_taxonomic_analysis.cwl/visualize_otu_counts/otu_visualization",
                            "id": "#16S_taxonomic_analysis.cwl/update_krona_chart_urls/krona_chart"
                        }
                    ],
                    "out": [
                        "#16S_taxonomic_analysis.cwl/update_krona_chart_urls/fixed_krona_chart"
                    ],
                    "id": "#16S_taxonomic_analysis.cwl/update_krona_chart_urls"
                },
                {
                    "run": "#krona.cwl",
                    "in": [
                        {
                            "source": "#16S_taxonomic_analysis.cwl/krona_setup/krona_input",
                            "id": "#16S_taxonomic_analysis.cwl/visualize_otu_counts/otu_counts"
                        }
                    ],
                    "out": [
                        "#16S_taxonomic_analysis.cwl/visualize_otu_counts/otu_visualization"
                    ],
                    "id": "#16S_taxonomic_analysis.cwl/visualize_otu_counts"
                }
            ],
            "id": "#16S_taxonomic_analysis.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "Workflow",
            "label": "EMG pipeline v3.0 (paired end version)",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "$import": "#FragGeneScan-model.yaml/model"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1370",
                    "id": "#main/16S_model"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1370",
                    "id": "#main/23S_model"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1370",
                    "id": "#main/5S_model"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "id": "#main/forward_reads"
                },
                {
                    "type": "#FragGeneScan-model.yaml/model",
                    "id": "#main/fraggenescan_model"
                },
                {
                    "type": "File",
                    "id": "#main/go_summary_config"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "id": "#main/reverse_reads"
                },
                {
                    "type": "string",
                    "id": "#main/run_id"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1370",
                    "id": "#main/tRNA_model"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/unified_processing/16S_matches",
                    "id": "#main/16S_matches"
                },
                {
                    "type": "File",
                    "outputSource": "#main/unified_processing/23S_matches",
                    "id": "#main/23S_matches"
                },
                {
                    "type": "File",
                    "outputSource": "#main/unified_processing/5S_matches",
                    "id": "#main/5S_matches"
                },
                {
                    "type": "string",
                    "outputSource": "#main/run_id",
                    "id": "#main/actual_run_id"
                },
                {
                    "type": "File",
                    "outputSource": "#main/unified_processing/annotated_CDS_aa",
                    "id": "#main/annotated_CDS_aa"
                },
                {
                    "type": "File",
                    "outputSource": "#main/unified_processing/annotated_CDS_nuc",
                    "id": "#main/annotated_CDS_nuc"
                },
                {
                    "type": "File",
                    "outputSource": "#main/unified_processing/biom_hdf5",
                    "id": "#main/biom_hdf5"
                },
                {
                    "type": "File",
                    "outputSource": "#main/unified_processing/biom_json",
                    "id": "#main/biom_json"
                },
                {
                    "type": "File",
                    "outputSource": "#main/unified_processing/biom_tsv",
                    "id": "#main/biom_tsv"
                },
                {
                    "type": "File",
                    "outputSource": "#main/unified_processing/functional_annotations",
                    "id": "#main/functional_annotations"
                },
                {
                    "type": "File",
                    "outputSource": "#main/unified_processing/go_summary",
                    "id": "#main/go_summary"
                },
                {
                    "type": "File",
                    "outputSource": "#main/unified_processing/go_summary_slim",
                    "id": "#main/go_summary_slim"
                },
                {
                    "type": "File",
                    "outputSource": "#main/unified_processing/interproscan_matches",
                    "id": "#main/interproscan_matches"
                },
                {
                    "type": "int",
                    "outputSource": "#main/unified_processing/ipr_CDS_with_match_count",
                    "id": "#main/ipr_CDS_with_match_count"
                },
                {
                    "type": "int",
                    "outputSource": "#main/unified_processing/ipr_match_count",
                    "id": "#main/ipr_match_count"
                },
                {
                    "type": "File",
                    "outputSource": "#main/unified_processing/ipr_reads",
                    "id": "#main/ipr_reads"
                },
                {
                    "type": "int",
                    "outputSource": "#main/unified_processing/ipr_reads_with_match_count",
                    "id": "#main/ipr_reads_with_match_count"
                },
                {
                    "type": "File",
                    "outputSource": "#main/unified_processing/ipr_summary",
                    "id": "#main/ipr_summary"
                },
                {
                    "type": "File",
                    "outputSource": "#main/unified_processing/kingdom_counts",
                    "id": "#main/kingdom_counts"
                },
                {
                    "type": "File",
                    "outputSource": "#main/unified_processing/krona_input",
                    "id": "#main/krona_input"
                },
                {
                    "type": "File",
                    "outputSource": "#main/unified_processing/no_functions_seqs",
                    "id": "#main/no_functions_seqs"
                },
                {
                    "type": "File",
                    "outputSource": "#main/unified_processing/otu_table_summary",
                    "id": "#main/otu_table_summary"
                },
                {
                    "type": "File",
                    "outputSource": "#main/unified_processing/otu_visualization",
                    "id": "#main/otu_visualization"
                },
                {
                    "type": "File",
                    "outputSource": "#main/unified_processing/pCDS_seqs",
                    "id": "#main/pCDS_seqs"
                },
                {
                    "type": "int",
                    "outputSource": "#main/unified_processing/post_qc_read_count",
                    "id": "#main/post_qc_read_count"
                },
                {
                    "type": "File",
                    "outputSource": "#main/unified_processing/post_qc_reads",
                    "id": "#main/post_qc_reads"
                },
                {
                    "type": "File",
                    "outputSource": "#main/unified_processing/predicted_CDS_aa",
                    "id": "#main/predicted_CDS_aa"
                },
                {
                    "type": "File",
                    "outputSource": "#main/unified_processing/processed_sequences",
                    "id": "#main/processed_sequences"
                },
                {
                    "type": "File",
                    "outputSource": "#main/unified_processing/qc_stats_gc",
                    "id": "#main/qc_stats_gc"
                },
                {
                    "type": "File",
                    "outputSource": "#main/unified_processing/qc_stats_gc_bin",
                    "id": "#main/qc_stats_gc_bin"
                },
                {
                    "type": "File",
                    "outputSource": "#main/unified_processing/qc_stats_gc_pcbin",
                    "id": "#main/qc_stats_gc_pcbin"
                },
                {
                    "type": "File",
                    "outputSource": "#main/unified_processing/qc_stats_nuc_dist",
                    "id": "#main/qc_stats_nuc_dist"
                },
                {
                    "type": "File",
                    "outputSource": "#main/unified_processing/qc_stats_seq_len",
                    "id": "#main/qc_stats_seq_len"
                },
                {
                    "type": "File",
                    "outputSource": "#main/unified_processing/qc_stats_seq_len_bin",
                    "id": "#main/qc_stats_seq_len_bin"
                },
                {
                    "type": "File",
                    "outputSource": "#main/unified_processing/qc_stats_seq_len_pbcbin",
                    "id": "#main/qc_stats_seq_len_pbcbin"
                },
                {
                    "type": "File",
                    "outputSource": "#main/unified_processing/qc_stats_summary",
                    "id": "#main/qc_stats_summary"
                },
                {
                    "type": "File",
                    "outputSource": "#main/unified_processing/qiime_assigned_taxonomy",
                    "id": "#main/qiime_assigned_taxonomy"
                },
                {
                    "type": "File",
                    "outputSource": "#main/unified_processing/qiime_sequences-filtered_clusters",
                    "id": "#main/qiime_sequences-filtered_clusters"
                },
                {
                    "type": "File",
                    "outputSource": "#main/unified_processing/qiime_sequences-filtered_otus",
                    "id": "#main/qiime_sequences-filtered_otus"
                },
                {
                    "type": "File",
                    "outputSource": "#main/unified_processing/summary",
                    "id": "#main/summary"
                },
                {
                    "type": "File",
                    "outputSource": "#main/unified_processing/tRNA_matches",
                    "id": "#main/tRNA_matches"
                },
                {
                    "type": "File",
                    "outputSource": "#main/unified_processing/tree",
                    "id": "#main/tree"
                },
                {
                    "type": "File",
                    "outputSource": "#main/unified_processing/unannotated_CDS_aa",
                    "id": "#main/unannotated_CDS_aa"
                },
                {
                    "type": "File",
                    "outputSource": "#main/unified_processing/unannotated_CDS_nuc",
                    "id": "#main/unannotated_CDS_nuc"
                }
            ],
            "steps": [
                {
                    "run": "#seqprep-merge.cwl",
                    "in": [
                        {
                            "source": "#main/overlap_reads/forward_unmerged_reads",
                            "id": "#main/combine_overlaped_and_unmerged_reads/forward_unmerged_reads"
                        },
                        {
                            "source": "#main/overlap_reads/merged_reads",
                            "id": "#main/combine_overlaped_and_unmerged_reads/merged_reads"
                        },
                        {
                            "source": "#main/overlap_reads/reverse_unmerged_reads",
                            "id": "#main/combine_overlaped_and_unmerged_reads/reverse_unmerged_reads"
                        }
                    ],
                    "out": [
                        "#main/combine_overlaped_and_unmerged_reads/merged_with_unmerged_reads"
                    ],
                    "id": "#main/combine_overlaped_and_unmerged_reads"
                },
                {
                    "label": "Paired-end overlapping reads are merged",
                    "run": "#seqprep.cwl",
                    "in": [
                        {
                            "source": "#main/forward_reads",
                            "id": "#main/overlap_reads/forward_reads"
                        },
                        {
                            "source": "#main/reverse_reads",
                            "id": "#main/overlap_reads/reverse_reads"
                        }
                    ],
                    "out": [
                        "#main/overlap_reads/merged_reads",
                        "#main/overlap_reads/forward_unmerged_reads",
                        "#main/overlap_reads/reverse_unmerged_reads"
                    ],
                    "id": "#main/overlap_reads"
                },
                {
                    "label": "continue with the main workflow",
                    "run": "#emg-pipeline-v3.cwl",
                    "in": [
                        {
                            "source": "#main/16S_model",
                            "id": "#main/unified_processing/16S_model"
                        },
                        {
                            "source": "#main/23S_model",
                            "id": "#main/unified_processing/23S_model"
                        },
                        {
                            "source": "#main/5S_model",
                            "id": "#main/unified_processing/5S_model"
                        },
                        {
                            "source": "#main/fraggenescan_model",
                            "id": "#main/unified_processing/fraggenescan_model"
                        },
                        {
                            "source": "#main/go_summary_config",
                            "id": "#main/unified_processing/go_summary_config"
                        },
                        {
                            "source": "#main/combine_overlaped_and_unmerged_reads/merged_with_unmerged_reads",
                            "id": "#main/unified_processing/reads"
                        },
                        {
                            "source": "#main/run_id",
                            "id": "#main/unified_processing/run_id"
                        },
                        {
                            "source": "#main/tRNA_model",
                            "id": "#main/unified_processing/tRNA_model"
                        }
                    ],
                    "out": [
                        "#main/unified_processing/processed_sequences",
                        "#main/unified_processing/predicted_CDS_aa",
                        "#main/unified_processing/functional_annotations",
                        "#main/unified_processing/go_summary",
                        "#main/unified_processing/go_summary_slim",
                        "#main/unified_processing/otu_table_summary",
                        "#main/unified_processing/tree",
                        "#main/unified_processing/biom_json",
                        "#main/unified_processing/biom_hdf5",
                        "#main/unified_processing/biom_tsv",
                        "#main/unified_processing/qc_stats_summary",
                        "#main/unified_processing/qc_stats_seq_len_pbcbin",
                        "#main/unified_processing/qc_stats_seq_len_bin",
                        "#main/unified_processing/qc_stats_seq_len",
                        "#main/unified_processing/qc_stats_nuc_dist",
                        "#main/unified_processing/qc_stats_gc_pcbin",
                        "#main/unified_processing/qc_stats_gc_bin",
                        "#main/unified_processing/qc_stats_gc",
                        "#main/unified_processing/ipr_match_count",
                        "#main/unified_processing/ipr_CDS_with_match_count",
                        "#main/unified_processing/ipr_reads_with_match_count",
                        "#main/unified_processing/ipr_reads",
                        "#main/unified_processing/ipr_summary",
                        "#main/unified_processing/annotated_CDS_nuc",
                        "#main/unified_processing/annotated_CDS_aa",
                        "#main/unified_processing/unannotated_CDS_nuc",
                        "#main/unified_processing/unannotated_CDS_aa",
                        "#main/unified_processing/qiime_sequences-filtered_clusters",
                        "#main/unified_processing/qiime_sequences-filtered_otus",
                        "#main/unified_processing/qiime_assigned_taxonomy",
                        "#main/unified_processing/tRNA_matches",
                        "#main/unified_processing/16S_matches",
                        "#main/unified_processing/23S_matches",
                        "#main/unified_processing/5S_matches",
                        "#main/unified_processing/interproscan_matches",
                        "#main/unified_processing/pCDS_seqs",
                        "#main/unified_processing/no_functions_seqs",
                        "#main/unified_processing/post_qc_reads",
                        "#main/unified_processing/post_qc_read_count",
                        "#main/unified_processing/summary",
                        "#main/unified_processing/krona_input",
                        "#main/unified_processing/kingdom_counts",
                        "#main/unified_processing/otu_visualization"
                    ],
                    "id": "#main/unified_processing"
                }
            ],
            "id": "#main",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "Workflow",
            "label": "EMG pipeline v3.0 (single end version)",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "$import": "#FragGeneScan-model.yaml/model"
                        },
                        {
                            "$import": "#trimmomatic-sliding_window.yaml/slidingWindow"
                        },
                        {
                            "$import": "#trimmomatic-end_mode.yaml/end_mode"
                        },
                        {
                            "$import": "#trimmomatic-phred.yaml/phred"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1370",
                    "id": "#emg-pipeline-v3.cwl/16S_model"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1370",
                    "id": "#emg-pipeline-v3.cwl/23S_model"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1370",
                    "id": "#emg-pipeline-v3.cwl/5S_model"
                },
                {
                    "type": "#FragGeneScan-model.yaml/model",
                    "id": "#emg-pipeline-v3.cwl/fraggenescan_model"
                },
                {
                    "type": "File",
                    "id": "#emg-pipeline-v3.cwl/go_summary_config"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "id": "#emg-pipeline-v3.cwl/reads"
                },
                {
                    "type": "string",
                    "id": "#emg-pipeline-v3.cwl/run_id"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1370",
                    "id": "#emg-pipeline-v3.cwl/tRNA_model"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "outputSource": "#emg-pipeline-v3.cwl/find_SSUs_and_mask/16S_matches",
                    "id": "#emg-pipeline-v3.cwl/16S_matches"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "outputSource": "#emg-pipeline-v3.cwl/find_SSUs_and_mask/23S_matches",
                    "id": "#emg-pipeline-v3.cwl/23S_matches"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "outputSource": "#emg-pipeline-v3.cwl/find_SSUs_and_mask/5S_matches",
                    "id": "#emg-pipeline-v3.cwl/5S_matches"
                },
                {
                    "type": "string",
                    "outputSource": "#emg-pipeline-v3.cwl/run_id",
                    "id": "#emg-pipeline-v3.cwl/actual_run_id"
                },
                {
                    "type": "File",
                    "outputSource": "#emg-pipeline-v3.cwl/relabel_annotated_cds_aa_seqs/relabeled_sequences",
                    "id": "#emg-pipeline-v3.cwl/annotated_CDS_aa"
                },
                {
                    "type": "File",
                    "outputSource": "#emg-pipeline-v3.cwl/relabel_annotated_cds_nuc_seqs/relabeled_sequences",
                    "id": "#emg-pipeline-v3.cwl/annotated_CDS_nuc"
                },
                {
                    "type": "File",
                    "outputSource": "#emg-pipeline-v3.cwl/16S_taxonomic_analysis/biom_hdf5",
                    "id": "#emg-pipeline-v3.cwl/biom_hdf5"
                },
                {
                    "type": "File",
                    "outputSource": "#emg-pipeline-v3.cwl/16S_taxonomic_analysis/biom_json",
                    "id": "#emg-pipeline-v3.cwl/biom_json"
                },
                {
                    "type": "File",
                    "outputSource": "#emg-pipeline-v3.cwl/16S_taxonomic_analysis/biom_tsv",
                    "id": "#emg-pipeline-v3.cwl/biom_tsv"
                },
                {
                    "type": "File",
                    "outputSource": "#emg-pipeline-v3.cwl/functional_analysis/functional_annotations",
                    "id": "#emg-pipeline-v3.cwl/functional_annotations"
                },
                {
                    "type": "File",
                    "outputSource": "#emg-pipeline-v3.cwl/functional_analysis/go_summary",
                    "id": "#emg-pipeline-v3.cwl/go_summary"
                },
                {
                    "type": "File",
                    "outputSource": "#emg-pipeline-v3.cwl/functional_analysis/go_summary_slim",
                    "id": "#emg-pipeline-v3.cwl/go_summary_slim"
                },
                {
                    "type": "File",
                    "outputSource": "#emg-pipeline-v3.cwl/categorisation/interproscan",
                    "id": "#emg-pipeline-v3.cwl/interproscan_matches"
                },
                {
                    "type": "int",
                    "outputSource": "#emg-pipeline-v3.cwl/ipr_stats/CDS_with_match_count",
                    "id": "#emg-pipeline-v3.cwl/ipr_CDS_with_match_count"
                },
                {
                    "type": "int",
                    "outputSource": "#emg-pipeline-v3.cwl/ipr_stats/match_count",
                    "id": "#emg-pipeline-v3.cwl/ipr_match_count"
                },
                {
                    "type": "File",
                    "outputSource": "#emg-pipeline-v3.cwl/ipr_stats/reads",
                    "id": "#emg-pipeline-v3.cwl/ipr_reads"
                },
                {
                    "type": "int",
                    "outputSource": "#emg-pipeline-v3.cwl/ipr_stats/reads_with_match_count",
                    "id": "#emg-pipeline-v3.cwl/ipr_reads_with_match_count"
                },
                {
                    "type": "File",
                    "outputSource": "#emg-pipeline-v3.cwl/generate_ipr_summary/ipr_summary",
                    "id": "#emg-pipeline-v3.cwl/ipr_summary"
                },
                {
                    "type": "File",
                    "outputSource": "#emg-pipeline-v3.cwl/16S_taxonomic_analysis/kingdom_counts",
                    "id": "#emg-pipeline-v3.cwl/kingdom_counts"
                },
                {
                    "type": "File",
                    "outputSource": "#emg-pipeline-v3.cwl/16S_taxonomic_analysis/krona_input",
                    "id": "#emg-pipeline-v3.cwl/krona_input"
                },
                {
                    "type": "File",
                    "outputSource": "#emg-pipeline-v3.cwl/categorisation/no_functions_seqs",
                    "id": "#emg-pipeline-v3.cwl/no_functions_seqs"
                },
                {
                    "type": "File",
                    "outputSource": "#emg-pipeline-v3.cwl/16S_taxonomic_analysis/otu_table_summary",
                    "id": "#emg-pipeline-v3.cwl/otu_table_summary"
                },
                {
                    "type": "File",
                    "outputSource": "#emg-pipeline-v3.cwl/16S_taxonomic_analysis/otu_visualization",
                    "id": "#emg-pipeline-v3.cwl/otu_visualization"
                },
                {
                    "type": "File",
                    "outputSource": "#emg-pipeline-v3.cwl/categorisation/pCDS_seqs",
                    "id": "#emg-pipeline-v3.cwl/pCDS_seqs"
                },
                {
                    "type": "int",
                    "outputSource": "#emg-pipeline-v3.cwl/count_processed_reads/count",
                    "id": "#emg-pipeline-v3.cwl/post_qc_read_count"
                },
                {
                    "type": "File",
                    "outputSource": "#emg-pipeline-v3.cwl/convert_trimmed-reads_to_fasta/fasta",
                    "id": "#emg-pipeline-v3.cwl/post_qc_reads"
                },
                {
                    "type": "File",
                    "outputSource": "#emg-pipeline-v3.cwl/clean_fasta_headers/sequences_with_cleaned_headers",
                    "id": "#emg-pipeline-v3.cwl/post_sequences"
                },
                {
                    "type": "File",
                    "outputSource": "#emg-pipeline-v3.cwl/ORF_prediction/predicted_CDS_aa",
                    "id": "#emg-pipeline-v3.cwl/predicted_CDS_aa"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "outputSource": "#emg-pipeline-v3.cwl/find_SSUs_and_mask/masked_sequences",
                    "id": "#emg-pipeline-v3.cwl/processed_sequences"
                },
                {
                    "type": "File",
                    "outputSource": "#emg-pipeline-v3.cwl/sequence_stats/gc_sum_out",
                    "id": "#emg-pipeline-v3.cwl/qc_stats_gc"
                },
                {
                    "type": "File",
                    "outputSource": "#emg-pipeline-v3.cwl/sequence_stats/gc_sum_bin",
                    "id": "#emg-pipeline-v3.cwl/qc_stats_gc_bin"
                },
                {
                    "type": "File",
                    "outputSource": "#emg-pipeline-v3.cwl/sequence_stats/gc_sum_pcbin",
                    "id": "#emg-pipeline-v3.cwl/qc_stats_gc_pcbin"
                },
                {
                    "type": "File",
                    "outputSource": "#emg-pipeline-v3.cwl/sequence_stats/nucleotide_distribution_out",
                    "id": "#emg-pipeline-v3.cwl/qc_stats_nuc_dist"
                },
                {
                    "type": "File",
                    "outputSource": "#emg-pipeline-v3.cwl/sequence_stats/seq_length_out",
                    "id": "#emg-pipeline-v3.cwl/qc_stats_seq_len"
                },
                {
                    "type": "File",
                    "outputSource": "#emg-pipeline-v3.cwl/sequence_stats/seq_length_bin",
                    "id": "#emg-pipeline-v3.cwl/qc_stats_seq_len_bin"
                },
                {
                    "type": "File",
                    "outputSource": "#emg-pipeline-v3.cwl/sequence_stats/seq_length_pcbin",
                    "id": "#emg-pipeline-v3.cwl/qc_stats_seq_len_pbcbin"
                },
                {
                    "type": "File",
                    "outputSource": "#emg-pipeline-v3.cwl/sequence_stats/summary_out",
                    "id": "#emg-pipeline-v3.cwl/qc_stats_summary"
                },
                {
                    "type": "File",
                    "outputSource": "#emg-pipeline-v3.cwl/16S_taxonomic_analysis/qiime_assigned_taxonomy",
                    "id": "#emg-pipeline-v3.cwl/qiime_assigned_taxonomy"
                },
                {
                    "type": "File",
                    "outputSource": "#emg-pipeline-v3.cwl/16S_taxonomic_analysis/qiime_sequences-filtered_clusters",
                    "id": "#emg-pipeline-v3.cwl/qiime_sequences-filtered_clusters"
                },
                {
                    "type": "File",
                    "outputSource": "#emg-pipeline-v3.cwl/16S_taxonomic_analysis/qiime_sequences-filtered_otus",
                    "id": "#emg-pipeline-v3.cwl/qiime_sequences-filtered_otus"
                },
                {
                    "type": "File",
                    "outputSource": "#emg-pipeline-v3.cwl/generate_summary/summary",
                    "id": "#emg-pipeline-v3.cwl/summary"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "outputSource": "#emg-pipeline-v3.cwl/find_SSUs_and_mask/tRNA_matches",
                    "id": "#emg-pipeline-v3.cwl/tRNA_matches"
                },
                {
                    "type": "File",
                    "outputSource": "#emg-pipeline-v3.cwl/16S_taxonomic_analysis/tree",
                    "id": "#emg-pipeline-v3.cwl/tree"
                },
                {
                    "type": "File",
                    "outputSource": "#emg-pipeline-v3.cwl/divide_faa/rejected_sequences",
                    "id": "#emg-pipeline-v3.cwl/unannotated_CDS_aa"
                },
                {
                    "type": "File",
                    "outputSource": "#emg-pipeline-v3.cwl/divide_ffn/rejected_sequences",
                    "id": "#emg-pipeline-v3.cwl/unannotated_CDS_nuc"
                }
            ],
            "steps": [
                {
                    "doc": "16s rRNA are annotated using the Greengenes reference database\n(default closed-reference OTU picking protocol with Greengenes\n13.8 reference with reverse strand matching enabled).\n",
                    "run": "#16S_taxonomic_analysis.cwl",
                    "in": [
                        {
                            "source": "#emg-pipeline-v3.cwl/find_SSUs_and_mask/16S_matches",
                            "id": "#emg-pipeline-v3.cwl/16S_taxonomic_analysis/16S_matches"
                        }
                    ],
                    "out": [
                        "#emg-pipeline-v3.cwl/16S_taxonomic_analysis/otu_table_summary",
                        "#emg-pipeline-v3.cwl/16S_taxonomic_analysis/tree",
                        "#emg-pipeline-v3.cwl/16S_taxonomic_analysis/biom_json",
                        "#emg-pipeline-v3.cwl/16S_taxonomic_analysis/biom_hdf5",
                        "#emg-pipeline-v3.cwl/16S_taxonomic_analysis/biom_tsv",
                        "#emg-pipeline-v3.cwl/16S_taxonomic_analysis/qiime_sequences-filtered_clusters",
                        "#emg-pipeline-v3.cwl/16S_taxonomic_analysis/qiime_sequences-filtered_otus",
                        "#emg-pipeline-v3.cwl/16S_taxonomic_analysis/qiime_assigned_taxonomy",
                        "#emg-pipeline-v3.cwl/16S_taxonomic_analysis/krona_input",
                        "#emg-pipeline-v3.cwl/16S_taxonomic_analysis/kingdom_counts",
                        "#emg-pipeline-v3.cwl/16S_taxonomic_analysis/otu_visualization"
                    ],
                    "id": "#emg-pipeline-v3.cwl/16S_taxonomic_analysis"
                },
                {
                    "run": "#orf_prediction.cwl",
                    "in": [
                        {
                            "default": false,
                            "id": "#emg-pipeline-v3.cwl/ORF_prediction/completeSeq"
                        },
                        {
                            "source": "#emg-pipeline-v3.cwl/fraggenescan_model",
                            "id": "#emg-pipeline-v3.cwl/ORF_prediction/model"
                        },
                        {
                            "source": "#emg-pipeline-v3.cwl/find_SSUs_and_mask/masked_sequences",
                            "id": "#emg-pipeline-v3.cwl/ORF_prediction/sequence"
                        }
                    ],
                    "out": [
                        "#emg-pipeline-v3.cwl/ORF_prediction/predicted_CDS_aa",
                        "#emg-pipeline-v3.cwl/ORF_prediction/predicted_CDS_nuc"
                    ],
                    "id": "#emg-pipeline-v3.cwl/ORF_prediction"
                },
                {
                    "run": "#create_categorisations.cwl",
                    "in": [
                        {
                            "source": "#emg-pipeline-v3.cwl/orf_stats/readsWithOrf",
                            "id": "#emg-pipeline-v3.cwl/categorisation/cds_idset"
                        },
                        {
                            "source": "#emg-pipeline-v3.cwl/ipr_stats/reads",
                            "id": "#emg-pipeline-v3.cwl/categorisation/ipr_idset"
                        },
                        {
                            "source": "#emg-pipeline-v3.cwl/find_SSUs_and_mask/masked_sequences",
                            "id": "#emg-pipeline-v3.cwl/categorisation/seqs"
                        }
                    ],
                    "out": [
                        "#emg-pipeline-v3.cwl/categorisation/interproscan",
                        "#emg-pipeline-v3.cwl/categorisation/pCDS_seqs",
                        "#emg-pipeline-v3.cwl/categorisation/no_functions_seqs"
                    ],
                    "id": "#emg-pipeline-v3.cwl/categorisation"
                },
                {
                    "run": "#clean_fasta_headers.cwl",
                    "in": [
                        {
                            "source": "#emg-pipeline-v3.cwl/convert_trimmed-reads_to_fasta/fasta",
                            "id": "#emg-pipeline-v3.cwl/clean_fasta_headers/sequences"
                        }
                    ],
                    "out": [
                        "#emg-pipeline-v3.cwl/clean_fasta_headers/sequences_with_cleaned_headers"
                    ],
                    "id": "#emg-pipeline-v3.cwl/clean_fasta_headers"
                },
                {
                    "run": "#fastq_to_fasta.cwl",
                    "in": [
                        {
                            "source": "#emg-pipeline-v3.cwl/trim_quality_control/reads1_trimmed",
                            "id": "#emg-pipeline-v3.cwl/convert_trimmed-reads_to_fasta/fastq"
                        }
                    ],
                    "out": [
                        "#emg-pipeline-v3.cwl/convert_trimmed-reads_to_fasta/fasta"
                    ],
                    "id": "#emg-pipeline-v3.cwl/convert_trimmed-reads_to_fasta"
                },
                {
                    "run": "#count_fasta.cwl",
                    "in": [
                        {
                            "source": "#emg-pipeline-v3.cwl/find_SSUs_and_mask/masked_sequences",
                            "id": "#emg-pipeline-v3.cwl/count_masked_reads/sequences"
                        }
                    ],
                    "out": [
                        "#emg-pipeline-v3.cwl/count_masked_reads/count"
                    ],
                    "id": "#emg-pipeline-v3.cwl/count_masked_reads"
                },
                {
                    "run": "#count_fasta.cwl",
                    "in": [
                        {
                            "source": "#emg-pipeline-v3.cwl/convert_trimmed-reads_to_fasta/fasta",
                            "id": "#emg-pipeline-v3.cwl/count_processed_reads/sequences"
                        }
                    ],
                    "out": [
                        "#emg-pipeline-v3.cwl/count_processed_reads/count"
                    ],
                    "id": "#emg-pipeline-v3.cwl/count_processed_reads"
                },
                {
                    "run": "#count_fastq.cwl",
                    "in": [
                        {
                            "source": "#emg-pipeline-v3.cwl/reads",
                            "id": "#emg-pipeline-v3.cwl/count_reads/sequences"
                        }
                    ],
                    "out": [
                        "#emg-pipeline-v3.cwl/count_reads/count"
                    ],
                    "id": "#emg-pipeline-v3.cwl/count_reads"
                },
                {
                    "run": "#faselector.cwl",
                    "in": [
                        {
                            "source": "#emg-pipeline-v3.cwl/ipr_stats/id_list",
                            "id": "#emg-pipeline-v3.cwl/divide_faa/id_list"
                        },
                        {
                            "source": "#emg-pipeline-v3.cwl/ORF_prediction/predicted_CDS_aa",
                            "id": "#emg-pipeline-v3.cwl/divide_faa/sequences"
                        }
                    ],
                    "out": [
                        "#emg-pipeline-v3.cwl/divide_faa/kept_sequences",
                        "#emg-pipeline-v3.cwl/divide_faa/rejected_sequences"
                    ],
                    "id": "#emg-pipeline-v3.cwl/divide_faa"
                },
                {
                    "run": "#faselector.cwl",
                    "in": [
                        {
                            "source": "#emg-pipeline-v3.cwl/ipr_stats/id_list",
                            "id": "#emg-pipeline-v3.cwl/divide_ffn/id_list"
                        },
                        {
                            "source": "#emg-pipeline-v3.cwl/ORF_prediction/predicted_CDS_nuc",
                            "id": "#emg-pipeline-v3.cwl/divide_ffn/sequences"
                        }
                    ],
                    "out": [
                        "#emg-pipeline-v3.cwl/divide_ffn/kept_sequences",
                        "#emg-pipeline-v3.cwl/divide_ffn/rejected_sequences"
                    ],
                    "id": "#emg-pipeline-v3.cwl/divide_ffn"
                },
                {
                    "run": "#extract_sig_coords.cwl",
                    "in": [
                        {
                            "source": "#emg-pipeline-v3.cwl/functional_analysis/functional_annotations",
                            "id": "#emg-pipeline-v3.cwl/extract_iprscan_coords/i5_annotations"
                        }
                    ],
                    "out": [
                        "#emg-pipeline-v3.cwl/extract_iprscan_coords/matches_coords"
                    ],
                    "id": "#emg-pipeline-v3.cwl/extract_iprscan_coords"
                },
                {
                    "run": "#rna-selector.cwl",
                    "in": [
                        {
                            "source": "#emg-pipeline-v3.cwl/16S_model",
                            "id": "#emg-pipeline-v3.cwl/find_SSUs_and_mask/16S_model"
                        },
                        {
                            "source": "#emg-pipeline-v3.cwl/23S_model",
                            "id": "#emg-pipeline-v3.cwl/find_SSUs_and_mask/23S_model"
                        },
                        {
                            "source": "#emg-pipeline-v3.cwl/5S_model",
                            "id": "#emg-pipeline-v3.cwl/find_SSUs_and_mask/5S_model"
                        },
                        {
                            "source": "#emg-pipeline-v3.cwl/clean_fasta_headers/sequences_with_cleaned_headers",
                            "id": "#emg-pipeline-v3.cwl/find_SSUs_and_mask/reads"
                        },
                        {
                            "source": "#emg-pipeline-v3.cwl/run_id",
                            "id": "#emg-pipeline-v3.cwl/find_SSUs_and_mask/run_id"
                        },
                        {
                            "source": "#emg-pipeline-v3.cwl/tRNA_model",
                            "id": "#emg-pipeline-v3.cwl/find_SSUs_and_mask/tRNA_model"
                        }
                    ],
                    "out": [
                        "#emg-pipeline-v3.cwl/find_SSUs_and_mask/16S_matches",
                        "#emg-pipeline-v3.cwl/find_SSUs_and_mask/23S_matches",
                        "#emg-pipeline-v3.cwl/find_SSUs_and_mask/5S_matches",
                        "#emg-pipeline-v3.cwl/find_SSUs_and_mask/tRNA_matches",
                        "#emg-pipeline-v3.cwl/find_SSUs_and_mask/masked_sequences"
                    ],
                    "id": "#emg-pipeline-v3.cwl/find_SSUs_and_mask"
                },
                {
                    "doc": "Matches are generated against predicted CDS, using a sub set of databases\n(Pfam, TIGRFAM, PRINTS, PROSITE patterns, Gene3d) from InterPro. \n",
                    "run": "#functional_analysis.cwl",
                    "in": [
                        {
                            "source": "#emg-pipeline-v3.cwl/go_summary_config",
                            "id": "#emg-pipeline-v3.cwl/functional_analysis/go_summary_config"
                        },
                        {
                            "source": "#emg-pipeline-v3.cwl/ORF_prediction/predicted_CDS_aa",
                            "id": "#emg-pipeline-v3.cwl/functional_analysis/predicted_CDS"
                        }
                    ],
                    "out": [
                        "#emg-pipeline-v3.cwl/functional_analysis/functional_annotations",
                        "#emg-pipeline-v3.cwl/functional_analysis/go_summary",
                        "#emg-pipeline-v3.cwl/functional_analysis/go_summary_slim"
                    ],
                    "id": "#emg-pipeline-v3.cwl/functional_analysis"
                },
                {
                    "run": "#write_ipr_summary.cwl",
                    "in": [
                        {
                            "source": "#emg-pipeline-v3.cwl/ipr_stats/ipr_entry_maps",
                            "id": "#emg-pipeline-v3.cwl/generate_ipr_summary/ipr_entry_maps"
                        }
                    ],
                    "out": [
                        "#emg-pipeline-v3.cwl/generate_ipr_summary/ipr_summary"
                    ],
                    "id": "#emg-pipeline-v3.cwl/generate_ipr_summary"
                },
                {
                    "run": "#summary.cwl",
                    "in": [
                        {
                            "source": "#emg-pipeline-v3.cwl/ipr_stats/CDS_with_match_count",
                            "id": "#emg-pipeline-v3.cwl/generate_summary/CDS_with_match"
                        },
                        {
                            "source": "#emg-pipeline-v3.cwl/ipr_stats/match_count",
                            "id": "#emg-pipeline-v3.cwl/generate_summary/IPS_matches"
                        },
                        {
                            "source": "#emg-pipeline-v3.cwl/count_processed_reads/count",
                            "id": "#emg-pipeline-v3.cwl/generate_summary/initial_filtered_count"
                        },
                        {
                            "source": "#emg-pipeline-v3.cwl/orf_stats/numberOrfs",
                            "id": "#emg-pipeline-v3.cwl/generate_summary/predicted_CDS_count"
                        },
                        {
                            "source": "#emg-pipeline-v3.cwl/ipr_stats/reads_with_match_count",
                            "id": "#emg-pipeline-v3.cwl/generate_summary/reads_with_match"
                        },
                        {
                            "source": "#emg-pipeline-v3.cwl/orf_stats/numberReadsWithOrf",
                            "id": "#emg-pipeline-v3.cwl/generate_summary/reads_with_orf"
                        },
                        {
                            "source": "#emg-pipeline-v3.cwl/count_masked_reads/count",
                            "id": "#emg-pipeline-v3.cwl/generate_summary/rna_count"
                        },
                        {
                            "source": "#emg-pipeline-v3.cwl/count_reads/count",
                            "id": "#emg-pipeline-v3.cwl/generate_summary/submitted_count"
                        }
                    ],
                    "out": [
                        "#emg-pipeline-v3.cwl/generate_summary/summary"
                    ],
                    "id": "#emg-pipeline-v3.cwl/generate_summary"
                },
                {
                    "run": "#ipr_stats.cwl",
                    "in": [
                        {
                            "source": "#emg-pipeline-v3.cwl/functional_analysis/functional_annotations",
                            "id": "#emg-pipeline-v3.cwl/ipr_stats/iprscan"
                        }
                    ],
                    "out": [
                        "#emg-pipeline-v3.cwl/ipr_stats/match_count",
                        "#emg-pipeline-v3.cwl/ipr_stats/CDS_with_match_count",
                        "#emg-pipeline-v3.cwl/ipr_stats/reads_with_match_count",
                        "#emg-pipeline-v3.cwl/ipr_stats/reads",
                        "#emg-pipeline-v3.cwl/ipr_stats/id_list",
                        "#emg-pipeline-v3.cwl/ipr_stats/ipr_entry_maps"
                    ],
                    "id": "#emg-pipeline-v3.cwl/ipr_stats"
                },
                {
                    "run": "#orf_stats.cwl",
                    "in": [
                        {
                            "source": "#emg-pipeline-v3.cwl/ORF_prediction/predicted_CDS_aa",
                            "id": "#emg-pipeline-v3.cwl/orf_stats/orfs"
                        }
                    ],
                    "out": [
                        "#emg-pipeline-v3.cwl/orf_stats/numberReadsWithOrf",
                        "#emg-pipeline-v3.cwl/orf_stats/numberOrfs",
                        "#emg-pipeline-v3.cwl/orf_stats/readsWithOrf"
                    ],
                    "id": "#emg-pipeline-v3.cwl/orf_stats"
                },
                {
                    "run": "#map_fa_headers.cwl",
                    "in": [
                        {
                            "default": true,
                            "id": "#emg-pipeline-v3.cwl/relabel_annotated_cds_aa_seqs/append"
                        },
                        {
                            "source": "#emg-pipeline-v3.cwl/extract_iprscan_coords/matches_coords",
                            "id": "#emg-pipeline-v3.cwl/relabel_annotated_cds_aa_seqs/header_mapping"
                        },
                        {
                            "source": "#emg-pipeline-v3.cwl/divide_faa/kept_sequences",
                            "id": "#emg-pipeline-v3.cwl/relabel_annotated_cds_aa_seqs/sequences"
                        }
                    ],
                    "out": [
                        "#emg-pipeline-v3.cwl/relabel_annotated_cds_aa_seqs/relabeled_sequences"
                    ],
                    "id": "#emg-pipeline-v3.cwl/relabel_annotated_cds_aa_seqs"
                },
                {
                    "run": "#map_fa_headers.cwl",
                    "in": [
                        {
                            "default": true,
                            "id": "#emg-pipeline-v3.cwl/relabel_annotated_cds_nuc_seqs/append"
                        },
                        {
                            "source": "#emg-pipeline-v3.cwl/extract_iprscan_coords/matches_coords",
                            "id": "#emg-pipeline-v3.cwl/relabel_annotated_cds_nuc_seqs/header_mapping"
                        },
                        {
                            "source": "#emg-pipeline-v3.cwl/divide_ffn/kept_sequences",
                            "id": "#emg-pipeline-v3.cwl/relabel_annotated_cds_nuc_seqs/sequences"
                        }
                    ],
                    "out": [
                        "#emg-pipeline-v3.cwl/relabel_annotated_cds_nuc_seqs/relabeled_sequences"
                    ],
                    "id": "#emg-pipeline-v3.cwl/relabel_annotated_cds_nuc_seqs"
                },
                {
                    "run": "#qc-stats.cwl",
                    "in": [
                        {
                            "source": "#emg-pipeline-v3.cwl/clean_fasta_headers/sequences_with_cleaned_headers",
                            "id": "#emg-pipeline-v3.cwl/sequence_stats/QCed_reads"
                        }
                    ],
                    "out": [
                        "#emg-pipeline-v3.cwl/sequence_stats/summary_out",
                        "#emg-pipeline-v3.cwl/sequence_stats/seq_length_pcbin",
                        "#emg-pipeline-v3.cwl/sequence_stats/seq_length_bin",
                        "#emg-pipeline-v3.cwl/sequence_stats/seq_length_out",
                        "#emg-pipeline-v3.cwl/sequence_stats/nucleotide_distribution_out",
                        "#emg-pipeline-v3.cwl/sequence_stats/gc_sum_pcbin",
                        "#emg-pipeline-v3.cwl/sequence_stats/gc_sum_bin",
                        "#emg-pipeline-v3.cwl/sequence_stats/gc_sum_out"
                    ],
                    "id": "#emg-pipeline-v3.cwl/sequence_stats"
                },
                {
                    "doc": "Low quality trimming (low quality ends and sequences with < quality scores\nless than 15 over a 4 nucleotide wide window are removed)\n",
                    "run": "#trimmomatic.cwl",
                    "in": [
                        {
                            "default": "SE",
                            "id": "#emg-pipeline-v3.cwl/trim_quality_control/end_mode"
                        },
                        {
                            "default": 3,
                            "id": "#emg-pipeline-v3.cwl/trim_quality_control/leading"
                        },
                        {
                            "default": 100,
                            "id": "#emg-pipeline-v3.cwl/trim_quality_control/minlen"
                        },
                        {
                            "default": "33",
                            "id": "#emg-pipeline-v3.cwl/trim_quality_control/phred"
                        },
                        {
                            "source": "#emg-pipeline-v3.cwl/reads",
                            "id": "#emg-pipeline-v3.cwl/trim_quality_control/reads1"
                        },
                        {
                            "default": {
                                "windowSize": 4,
                                "requiredQuality": 15
                            },
                            "id": "#emg-pipeline-v3.cwl/trim_quality_control/slidingwindow"
                        },
                        {
                            "default": 3,
                            "id": "#emg-pipeline-v3.cwl/trim_quality_control/trailing"
                        }
                    ],
                    "out": [
                        "#emg-pipeline-v3.cwl/trim_quality_control/reads1_trimmed"
                    ],
                    "id": "#emg-pipeline-v3.cwl/trim_quality_control"
                }
            ],
            "id": "#emg-pipeline-v3.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "Workflow",
            "label": "functional analysis prediction with InterProScan",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "$import": "#esl-reformat-replace.yaml/replace"
                        },
                        {
                            "$import": "#InterProScan-apps.yaml/apps"
                        },
                        {
                            "$import": "#InterProScan-protein_formats.yaml/protein_formats"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#functional_analysis.cwl/go_summary_config"
                },
                {
                    "type": "File",
                    "id": "#functional_analysis.cwl/predicted_CDS"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#functional_analysis.cwl/combine_annotations/result",
                    "id": "#functional_analysis.cwl/functional_annotations"
                },
                {
                    "type": "File",
                    "outputSource": "#functional_analysis.cwl/summarize_with_GO/go_summary",
                    "id": "#functional_analysis.cwl/go_summary"
                },
                {
                    "type": "File",
                    "outputSource": "#functional_analysis.cwl/summarize_with_GO/go_summary_slim",
                    "id": "#functional_analysis.cwl/go_summary_slim"
                }
            ],
            "steps": [
                {
                    "run": "#fasta_chunker.cwl",
                    "in": [
                        {
                            "default": 10000,
                            "id": "#functional_analysis.cwl/chunk_inputs/chunk_size"
                        },
                        {
                            "source": "#functional_analysis.cwl/remove_asterisks_and_reformat/reformatted_sequences",
                            "id": "#functional_analysis.cwl/chunk_inputs/seqs"
                        }
                    ],
                    "out": [
                        "#functional_analysis.cwl/chunk_inputs/chunks"
                    ],
                    "id": "#functional_analysis.cwl/chunk_inputs"
                },
                {
                    "run": "#concatenate.cwl",
                    "in": [
                        {
                            "source": "#functional_analysis.cwl/functional_analysis/i5Annotations",
                            "id": "#functional_analysis.cwl/combine_annotations/files"
                        }
                    ],
                    "out": [
                        "#functional_analysis.cwl/combine_annotations/result"
                    ],
                    "id": "#functional_analysis.cwl/combine_annotations"
                },
                {
                    "doc": "Matches are generated against predicted CDS, using a sub set of databases\n(Pfam, TIGRFAM, PRINTS, PROSITE patterns, Gene3d) from InterPro. \n",
                    "run": "#InterProScan5.21-60.cwl",
                    "in": [
                        {
                            "default": [
                                "Pfam",
                                "TIGRFAM",
                                "PRINTS",
                                "ProSitePatterns",
                                "Gene3D"
                            ],
                            "id": "#functional_analysis.cwl/functional_analysis/applications"
                        },
                        {
                            "source": "#functional_analysis.cwl/chunk_inputs/chunks",
                            "id": "#functional_analysis.cwl/functional_analysis/proteinFile"
                        }
                    ],
                    "scatter": "#functional_analysis.cwl/functional_analysis/proteinFile",
                    "out": [
                        "#functional_analysis.cwl/functional_analysis/i5Annotations"
                    ],
                    "id": "#functional_analysis.cwl/functional_analysis"
                },
                {
                    "run": "#esl-reformat.cwl",
                    "in": [
                        {
                            "default": {
                                "find": "*",
                                "replace": "X"
                            },
                            "id": "#functional_analysis.cwl/remove_asterisks_and_reformat/replace"
                        },
                        {
                            "source": "#functional_analysis.cwl/predicted_CDS",
                            "id": "#functional_analysis.cwl/remove_asterisks_and_reformat/sequences"
                        }
                    ],
                    "out": [
                        "#functional_analysis.cwl/remove_asterisks_and_reformat/reformatted_sequences"
                    ],
                    "id": "#functional_analysis.cwl/remove_asterisks_and_reformat"
                },
                {
                    "doc": "A summary of Gene Ontology (GO) terms derived from InterPro matches to\nthe sample. It is generated using a reduced list of GO terms called\nGO slim (http://www.geneontology.org/ontology/subsets/goslim_metagenomics.obo)\n",
                    "run": "#go_summary.cwl",
                    "in": [
                        {
                            "source": "#functional_analysis.cwl/combine_annotations/result",
                            "id": "#functional_analysis.cwl/summarize_with_GO/InterProScan_results"
                        },
                        {
                            "source": "#functional_analysis.cwl/go_summary_config",
                            "id": "#functional_analysis.cwl/summarize_with_GO/config"
                        }
                    ],
                    "out": [
                        "#functional_analysis.cwl/summarize_with_GO/go_summary",
                        "#functional_analysis.cwl/summarize_with_GO/go_summary_slim"
                    ],
                    "id": "#functional_analysis.cwl/summarize_with_GO"
                }
            ],
            "id": "#functional_analysis.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "Workflow",
            "label": "Find reads with predicted coding sequences above 60 AA in length",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "types": [
                        {
                            "$import": "#FragGeneScan-model.yaml/model"
                        }
                    ],
                    "class": "SchemaDefRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "boolean",
                    "id": "#orf_prediction.cwl/completeSeq"
                },
                {
                    "type": "#FragGeneScan-model.yaml/model",
                    "id": "#orf_prediction.cwl/model"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "id": "#orf_prediction.cwl/sequence"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "outputSource": "#orf_prediction.cwl/combine_predicted_CDS_aa/result",
                    "id": "#orf_prediction.cwl/predicted_CDS_aa"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "outputSource": "#orf_prediction.cwl/combine_predicted_CDS_nuc/result",
                    "id": "#orf_prediction.cwl/predicted_CDS_nuc"
                }
            ],
            "steps": [
                {
                    "doc": "Find reads with predicted coding sequences (pCDS)\n",
                    "run": "#FragGeneScan1_20.cwl",
                    "in": [
                        {
                            "source": "#orf_prediction.cwl/completeSeq",
                            "id": "#orf_prediction.cwl/ORF_prediction/completeSeq"
                        },
                        {
                            "source": "#orf_prediction.cwl/model",
                            "id": "#orf_prediction.cwl/ORF_prediction/model"
                        },
                        {
                            "source": "#orf_prediction.cwl/split_seqs/chunks",
                            "id": "#orf_prediction.cwl/ORF_prediction/sequence"
                        }
                    ],
                    "scatter": "#orf_prediction.cwl/ORF_prediction/sequence",
                    "out": [
                        "#orf_prediction.cwl/ORF_prediction/predicted_CDS_aa",
                        "#orf_prediction.cwl/ORF_prediction/predicted_CDS_nuc"
                    ],
                    "id": "#orf_prediction.cwl/ORF_prediction"
                },
                {
                    "run": "#concatenate.cwl",
                    "in": [
                        {
                            "source": "#orf_prediction.cwl/ORF_prediction/predicted_CDS_aa",
                            "id": "#orf_prediction.cwl/combine_predicted_CDS_aa/files"
                        }
                    ],
                    "out": [
                        "#orf_prediction.cwl/combine_predicted_CDS_aa/result"
                    ],
                    "id": "#orf_prediction.cwl/combine_predicted_CDS_aa"
                },
                {
                    "run": "#concatenate.cwl",
                    "in": [
                        {
                            "source": "#orf_prediction.cwl/ORF_prediction/predicted_CDS_nuc",
                            "id": "#orf_prediction.cwl/combine_predicted_CDS_nuc/files"
                        }
                    ],
                    "out": [
                        "#orf_prediction.cwl/combine_predicted_CDS_nuc/result"
                    ],
                    "id": "#orf_prediction.cwl/combine_predicted_CDS_nuc"
                },
                {
                    "run": "#fasta_chunker.cwl",
                    "in": [
                        {
                            "default": 100000,
                            "id": "#orf_prediction.cwl/split_seqs/chunk_size"
                        },
                        {
                            "source": "#orf_prediction.cwl/sequence",
                            "id": "#orf_prediction.cwl/split_seqs/seqs"
                        }
                    ],
                    "out": [
                        "#orf_prediction.cwl/split_seqs/chunks"
                    ],
                    "id": "#orf_prediction.cwl/split_seqs"
                }
            ],
            "id": "#orf_prediction.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "Workflow",
            "label": "RNASelector as a CWL workflow",
            "doc": "https://doi.org/10.1007/s12275-011-1213-z",
            "requirements": [
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "$import": "#trimmomatic-sliding_window.yaml/slidingWindow"
                        },
                        {
                            "$import": "#trimmomatic-end_mode.yaml/end_mode"
                        },
                        {
                            "$import": "#trimmomatic-phred.yaml/phred"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1370",
                    "id": "#rna-selector.cwl/16S_model"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1370",
                    "id": "#rna-selector.cwl/23S_model"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1370",
                    "id": "#rna-selector.cwl/5S_model"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "id": "#rna-selector.cwl/reads"
                },
                {
                    "type": "string",
                    "id": "#rna-selector.cwl/run_id"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1370",
                    "id": "#rna-selector.cwl/tRNA_model"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "outputSource": "#rna-selector.cwl/prepend_header_for_QIIME/labeled_sequences",
                    "id": "#rna-selector.cwl/16S_matches"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "outputSource": "#rna-selector.cwl/find_23S_matches/matching_sequences",
                    "id": "#rna-selector.cwl/23S_matches"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "outputSource": "#rna-selector.cwl/find_5S_matches/matching_sequences",
                    "id": "#rna-selector.cwl/5S_matches"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "outputSource": "#rna-selector.cwl/mask_rRNA_and_tRNA/masked_sequences",
                    "id": "#rna-selector.cwl/masked_sequences"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "outputSource": "#rna-selector.cwl/find_tRNA_matches/matching_sequences",
                    "id": "#rna-selector.cwl/tRNA_matches"
                }
            ],
            "steps": [
                {
                    "run": "#collate_unique_SSU_headers.cwl",
                    "in": [
                        {
                            "source": [
                                "#rna-selector.cwl/find_16S_matches/hmmer_search_results",
                                "#rna-selector.cwl/find_23S_matches/hmmer_search_results",
                                "#rna-selector.cwl/find_5S_matches/hmmer_search_results"
                            ],
                            "id": "#rna-selector.cwl/collate_unique_rRNA_hmmer_hits/hits"
                        }
                    ],
                    "out": [
                        "#rna-selector.cwl/collate_unique_rRNA_hmmer_hits/unique_hits"
                    ],
                    "id": "#rna-selector.cwl/collate_unique_rRNA_hmmer_hits"
                },
                {
                    "run": "#collate_unique_SSU_headers.cwl",
                    "in": [
                        {
                            "source": "#rna-selector.cwl/find_tRNA_matches/hmmer_search_results",
                            "valueFrom": "${ return [ self ]; }",
                            "id": "#rna-selector.cwl/collate_unique_tRNA_hmmer_hits/hits"
                        }
                    ],
                    "out": [
                        "#rna-selector.cwl/collate_unique_tRNA_hmmer_hits/unique_hits"
                    ],
                    "id": "#rna-selector.cwl/collate_unique_tRNA_hmmer_hits"
                },
                {
                    "run": "#rRNA_selection.cwl",
                    "in": [
                        {
                            "source": "#rna-selector.cwl/index_reads/sequences_with_index",
                            "id": "#rna-selector.cwl/find_16S_matches/indexed_sequences"
                        },
                        {
                            "source": "#rna-selector.cwl/16S_model",
                            "id": "#rna-selector.cwl/find_16S_matches/model"
                        }
                    ],
                    "out": [
                        "#rna-selector.cwl/find_16S_matches/matching_sequences",
                        "#rna-selector.cwl/find_16S_matches/hmmer_search_results"
                    ],
                    "id": "#rna-selector.cwl/find_16S_matches"
                },
                {
                    "run": "#rRNA_selection.cwl",
                    "in": [
                        {
                            "source": "#rna-selector.cwl/index_reads/sequences_with_index",
                            "id": "#rna-selector.cwl/find_23S_matches/indexed_sequences"
                        },
                        {
                            "source": "#rna-selector.cwl/23S_model",
                            "id": "#rna-selector.cwl/find_23S_matches/model"
                        }
                    ],
                    "out": [
                        "#rna-selector.cwl/find_23S_matches/matching_sequences",
                        "#rna-selector.cwl/find_23S_matches/hmmer_search_results"
                    ],
                    "id": "#rna-selector.cwl/find_23S_matches"
                },
                {
                    "run": "#rRNA_selection.cwl",
                    "in": [
                        {
                            "source": "#rna-selector.cwl/index_reads/sequences_with_index",
                            "id": "#rna-selector.cwl/find_5S_matches/indexed_sequences"
                        },
                        {
                            "source": "#rna-selector.cwl/5S_model",
                            "id": "#rna-selector.cwl/find_5S_matches/model"
                        }
                    ],
                    "out": [
                        "#rna-selector.cwl/find_5S_matches/matching_sequences",
                        "#rna-selector.cwl/find_5S_matches/hmmer_search_results"
                    ],
                    "id": "#rna-selector.cwl/find_5S_matches"
                },
                {
                    "run": "#tRNA_selection.cwl",
                    "in": [
                        {
                            "source": "#rna-selector.cwl/index_reads/sequences_with_index",
                            "id": "#rna-selector.cwl/find_tRNA_matches/indexed_sequences"
                        },
                        {
                            "source": "#rna-selector.cwl/tRNA_model",
                            "id": "#rna-selector.cwl/find_tRNA_matches/model"
                        }
                    ],
                    "out": [
                        "#rna-selector.cwl/find_tRNA_matches/matching_sequences",
                        "#rna-selector.cwl/find_tRNA_matches/hmmer_search_results"
                    ],
                    "id": "#rna-selector.cwl/find_tRNA_matches"
                },
                {
                    "run": "#esl-sfetch-index.cwl",
                    "in": [
                        {
                            "source": "#rna-selector.cwl/reads",
                            "id": "#rna-selector.cwl/index_reads/sequences"
                        }
                    ],
                    "out": [
                        "#rna-selector.cwl/index_reads/sequences_with_index"
                    ],
                    "id": "#rna-selector.cwl/index_reads"
                },
                {
                    "run": "#mask_RNA.cwl",
                    "in": [
                        {
                            "source": "#rna-selector.cwl/find_16S_matches/hmmer_search_results",
                            "id": "#rna-selector.cwl/mask_rRNA_and_tRNA/16s_rRNA_hmmer_matches"
                        },
                        {
                            "source": "#rna-selector.cwl/find_23S_matches/hmmer_search_results",
                            "id": "#rna-selector.cwl/mask_rRNA_and_tRNA/23s_rRNA_hmmer_matches"
                        },
                        {
                            "source": "#rna-selector.cwl/find_5S_matches/hmmer_search_results",
                            "id": "#rna-selector.cwl/mask_rRNA_and_tRNA/5s_rRNA_hmmer_matches"
                        },
                        {
                            "source": "#rna-selector.cwl/index_reads/sequences_with_index",
                            "id": "#rna-selector.cwl/mask_rRNA_and_tRNA/sequences"
                        },
                        {
                            "source": "#rna-selector.cwl/find_tRNA_matches/hmmer_search_results",
                            "id": "#rna-selector.cwl/mask_rRNA_and_tRNA/tRNA_matches"
                        },
                        {
                            "source": "#rna-selector.cwl/collate_unique_rRNA_hmmer_hits/unique_hits",
                            "id": "#rna-selector.cwl/mask_rRNA_and_tRNA/unique_rRNA_hits"
                        },
                        {
                            "source": "#rna-selector.cwl/collate_unique_tRNA_hmmer_hits/unique_hits",
                            "id": "#rna-selector.cwl/mask_rRNA_and_tRNA/unique_tRNA_hits"
                        }
                    ],
                    "out": [
                        "#rna-selector.cwl/mask_rRNA_and_tRNA/masked_sequences"
                    ],
                    "id": "#rna-selector.cwl/mask_rRNA_and_tRNA"
                },
                {
                    "run": "#prepend_header.cwl",
                    "in": [
                        {
                            "source": "#rna-selector.cwl/run_id",
                            "id": "#rna-selector.cwl/prepend_header_for_QIIME/label"
                        },
                        {
                            "source": "#rna-selector.cwl/find_16S_matches/matching_sequences",
                            "id": "#rna-selector.cwl/prepend_header_for_QIIME/sequences"
                        }
                    ],
                    "out": [
                        "#rna-selector.cwl/prepend_header_for_QIIME/labeled_sequences"
                    ],
                    "id": "#rna-selector.cwl/prepend_header_for_QIIME"
                }
            ],
            "id": "#rna-selector.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        }
    ],
    "cwlVersion": "v1.0",
    "$schemas": [
        "http://edamontology.org/EDAM_1.16.owl"
    ],
    "$namespaces": {
        "edam": "http://edamontology.org/",
        "s": "http://schema.org/"
    }
}
